/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtMultimediaAPI_H
#define _QtMultimediaAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QCameraViewfinderSettingsControl__ViewfinderParameter 0
#define sipName_QCameraViewfinderSettingsControl__ViewfinderParameter &sipStrings_QtMultimedia[0]
#define sipNameNr_QCameraImageProcessingControl__ProcessingParameter 54
#define sipName_QCameraImageProcessingControl__ProcessingParameter &sipStrings_QtMultimedia[54]
#define sipNameNr_QCameraExposureControl__ExposureParameter 105
#define sipName_QCameraExposureControl__ExposureParameter &sipStrings_QtMultimedia[105]
#define sipNameNr_QCameraImageCapture__CaptureDestinations 147
#define sipName_QCameraImageCapture__CaptureDestinations &sipStrings_QtMultimedia[147]
#define sipNameNr_QCameraImageProcessing__WhiteBalanceMode 188
#define sipName_QCameraImageProcessing__WhiteBalanceMode &sipStrings_QtMultimedia[188]
#define sipNameNr_QCameraImageCapture__CaptureDestination 229
#define sipName_QCameraImageCapture__CaptureDestination &sipStrings_QtMultimedia[229]
#define sipNameNr_QVideoSurfaceFormat__YCbCrColorSpace 269
#define sipName_QVideoSurfaceFormat__YCbCrColorSpace &sipStrings_QtMultimedia[269]
#define sipNameNr_alternativeFrequenciesEnabledChanged 306
#define sipName_alternativeFrequenciesEnabledChanged &sipStrings_QtMultimedia[306]
#define sipNameNr_QCameraImageProcessing__ColorFilter 343
#define sipName_QCameraImageProcessing__ColorFilter &sipStrings_QtMultimedia[343]
#define sipNameNr_QCameraControl__PropertyChangeType 379
#define sipName_QCameraControl__PropertyChangeType &sipStrings_QtMultimedia[379]
#define sipNameNr_supportedViewfinderFrameRateRanges 414
#define sipName_supportedViewfinderFrameRateRanges &sipStrings_QtMultimedia[414]
#define sipNameNr_QCameraCaptureBufferFormatControl 449
#define sipName_QCameraCaptureBufferFormatControl &sipStrings_QtMultimedia[449]
#define sipNameNr_QCameraFeedbackControl__EventType 483
#define sipName_QCameraFeedbackControl__EventType &sipStrings_QtMultimedia[483]
#define sipNameNr_QCameraFocusZone__FocusZoneStatus 517
#define sipName_QCameraFocusZone__FocusZoneStatus &sipStrings_QtMultimedia[517]
#define sipNameNr_QCameraViewfinderSettingsControl2 551
#define sipName_QCameraViewfinderSettingsControl2 &sipStrings_QtMultimedia[551]
#define sipNameNr_QAbstractVideoBuffer__HandleType 585
#define sipName_QAbstractVideoBuffer__HandleType &sipStrings_QtMultimedia[585]
#define sipNameNr_QCameraCaptureDestinationControl 618
#define sipName_QCameraCaptureDestinationControl &sipStrings_QtMultimedia[618]
#define sipNameNr_QCameraViewfinderSettingsControl 651
#define sipName_QCameraViewfinderSettingsControl &sipStrings_QtMultimedia[651]
#define sipNameNr_684 684
#define sipName_684 &sipStrings_QtMultimedia[684]
#define sipNameNr_QMediaStreamsControl__StreamType 717
#define sipName_QMediaStreamsControl__StreamType &sipStrings_QtMultimedia[717]
#define sipNameNr_setAlternativeFrequenciesEnabled 750
#define sipName_setAlternativeFrequenciesEnabled &sipStrings_QtMultimedia[750]
#define sipNameNr_783 783
#define sipName_783 &sipStrings_QtMultimedia[783]
#define sipNameNr_815 815
#define sipName_815 &sipStrings_QtMultimedia[815]
#define sipNameNr_QMultimedia__AvailabilityStatus 847
#define sipName_QMultimedia__AvailabilityStatus &sipStrings_QtMultimedia[847]
#define sipNameNr_879 879
#define sipName_879 &sipStrings_QtMultimedia[879]
#define sipNameNr_isAlternativeFrequenciesEnabled 911
#define sipName_isAlternativeFrequenciesEnabled &sipStrings_QtMultimedia[911]
#define sipNameNr_supportedViewfinderPixelFormats 943
#define sipName_supportedViewfinderPixelFormats &sipStrings_QtMultimedia[943]
#define sipNameNr_QCameraImageCapture__DriveMode 975
#define sipName_QCameraImageCapture__DriveMode &sipStrings_QtMultimedia[975]
#define sipNameNr_1006 1006
#define sipName_1006 &sipStrings_QtMultimedia[1006]
#define sipNameNr_QVideoFilterRunnable__RunFlags 1037
#define sipName_QVideoFilterRunnable__RunFlags &sipStrings_QtMultimedia[1037]
#define sipNameNr_QVideoSurfaceFormat__Direction 1068
#define sipName_QVideoSurfaceFormat__Direction &sipStrings_QtMultimedia[1068]
#define sipNameNr_availablePlaybackRangesChanged 1099
#define sipName_availablePlaybackRangesChanged &sipStrings_QtMultimedia[1099]
#define sipNameNr_isViewfinderParameterSupported 1130
#define sipName_isViewfinderParameterSupported &sipStrings_QtMultimedia[1130]
#define sipNameNr_supportedViewfinderResolutions 1161
#define sipName_supportedViewfinderResolutions &sipStrings_QtMultimedia[1161]
#define sipNameNr_Format_ARGB8565_Premultiplied 1192
#define sipName_Format_ARGB8565_Premultiplied &sipStrings_QtMultimedia[1192]
#define sipNameNr_Format_BGRA5658_Premultiplied 1222
#define sipName_Format_BGRA5658_Premultiplied &sipStrings_QtMultimedia[1222]
#define sipNameNr_QAbstractVideoBuffer__MapMode 1252
#define sipName_QAbstractVideoBuffer__MapMode &sipStrings_QtMultimedia[1252]
#define sipNameNr_QCameraExposure__ExposureMode 1282
#define sipName_QCameraExposure__ExposureMode &sipStrings_QtMultimedia[1282]
#define sipNameNr_QCameraExposure__MeteringMode 1312
#define sipName_QCameraExposure__MeteringMode &sipStrings_QtMultimedia[1312]
#define sipNameNr_QCameraImageProcessingControl 1342
#define sipName_QCameraImageProcessingControl &sipStrings_QtMultimedia[1342]
#define sipNameNr_QVideoFilterRunnable__RunFlag 1372
#define sipName_QVideoFilterRunnable__RunFlag &sipStrings_QtMultimedia[1372]
#define sipNameNr_isCaptureDestinationSupported 1402
#define sipName_isCaptureDestinationSupported &sipStrings_QtMultimedia[1402]
#define sipNameNr_Format_AYUV444_Premultiplied 1432
#define sipName_Format_AYUV444_Premultiplied &sipStrings_QtMultimedia[1432]
#define sipNameNr_QAbstractVideoSurface__Error 1461
#define sipName_QAbstractVideoSurface__Error &sipStrings_QtMultimedia[1461]
#define sipNameNr_QAudioEncoderSettingsControl 1490
#define sipName_QAudioEncoderSettingsControl &sipStrings_QtMultimedia[1490]
#define sipNameNr_QCameraFocus__FocusPointMode 1519
#define sipName_QCameraFocus__FocusPointMode &sipStrings_QtMultimedia[1519]
#define sipNameNr_QMediaGaplessPlaybackControl 1548
#define sipName_QMediaGaplessPlaybackControl &sipStrings_QtMultimedia[1548]
#define sipNameNr_QMediaPlaylist__PlaybackMode 1577
#define sipName_QMediaPlaylist__PlaybackMode &sipStrings_QtMultimedia[1577]
#define sipNameNr_QMultimedia__EncodingQuality 1606
#define sipName_QMultimedia__EncodingQuality &sipStrings_QtMultimedia[1606]
#define sipNameNr_QMultimedia__SupportEstimate 1635
#define sipName_QMultimedia__SupportEstimate &sipStrings_QtMultimedia[1635]
#define sipNameNr_QVideoEncoderSettingsControl 1664
#define sipName_QVideoEncoderSettingsControl &sipStrings_QtMultimedia[1664]
#define sipNameNr_Format_ARGB32_Premultiplied 1693
#define sipName_Format_ARGB32_Premultiplied &sipStrings_QtMultimedia[1693]
#define sipNameNr_Format_BGRA32_Premultiplied 1721
#define sipName_Format_BGRA32_Premultiplied &sipStrings_QtMultimedia[1721]
#define sipNameNr_QAudioOutputSelectorControl 1749
#define sipName_QAudioOutputSelectorControl &sipStrings_QtMultimedia[1749]
#define sipNameNr_QCameraExposure__FlashModes 1777
#define sipName_QCameraExposure__FlashModes &sipStrings_QtMultimedia[1777]
#define sipNameNr_1805 1805
#define sipName_1805 &sipStrings_QtMultimedia[1805]
#define sipNameNr_QVideoDeviceSelectorControl 1833
#define sipName_QVideoDeviceSelectorControl &sipStrings_QtMultimedia[1833]
#define sipNameNr_availableAudioInputsChanged 1861
#define sipName_availableAudioInputsChanged &sipStrings_QtMultimedia[1861]
#define sipNameNr_currentNetworkConfiguration 1889
#define sipName_currentNetworkConfiguration &sipStrings_QtMultimedia[1889]
#define sipNameNr_exposureCompensationChanged 1917
#define sipName_exposureCompensationChanged &sipStrings_QtMultimedia[1917]
#define sipNameNr_isWhiteBalanceModeSupported 1945
#define sipName_isWhiteBalanceModeSupported &sipStrings_QtMultimedia[1945]
#define sipNameNr_networkConfigurationChanged 1973
#define sipName_networkConfigurationChanged &sipStrings_QtMultimedia[1973]
#define sipNameNr_requestedDigitalZoomChanged 2001
#define sipName_requestedDigitalZoomChanged &sipStrings_QtMultimedia[2001]
#define sipNameNr_requestedOpticalZoomChanged 2029
#define sipName_requestedOpticalZoomChanged &sipStrings_QtMultimedia[2029]
#define sipNameNr_supportedViewfinderSettings 2057
#define sipName_supportedViewfinderSettings &sipStrings_QtMultimedia[2057]
#define sipNameNr_QAudioInputSelectorControl 2085
#define sipName_QAudioInputSelectorControl &sipStrings_QtMultimedia[2085]
#define sipNameNr_QCameraExposure__FlashMode 2112
#define sipName_QCameraExposure__FlashMode &sipStrings_QtMultimedia[2112]
#define sipNameNr_QCameraImageCapture__Error 2139
#define sipName_QCameraImageCapture__Error &sipStrings_QtMultimedia[2139]
#define sipNameNr_QCameraImageCaptureControl 2166
#define sipName_QCameraImageCaptureControl &sipStrings_QtMultimedia[2166]
#define sipNameNr_QMediaNetworkAccessControl 2193
#define sipName_QMediaNetworkAccessControl &sipStrings_QtMultimedia[2193]
#define sipNameNr_imageFormatFromPixelFormat 2220
#define sipName_imageFormatFromPixelFormat &sipStrings_QtMultimedia[2220]
#define sipNameNr_pixelFormatFromImageFormat 2247
#define sipName_pixelFormatFromImageFormat &sipStrings_QtMultimedia[2247]
#define sipNameNr_ExtendedExposureParameter 2274
#define sipName_ExtendedExposureParameter &sipStrings_QtMultimedia[2274]
#define sipNameNr_FlashSlowSyncFrontCurtain 2300
#define sipName_FlashSlowSyncFrontCurtain &sipStrings_QtMultimedia[2300]
#define sipNameNr_QCamera__LockChangeReason 2326
#define sipName_QCamera__LockChangeReason &sipStrings_QtMultimedia[2326]
#define sipNameNr_QCameraViewfinderSettings 2352
#define sipName_QCameraViewfinderSettings &sipStrings_QtMultimedia[2352]
#define sipNameNr_2378 2378
#define sipName_2378 &sipStrings_QtMultimedia[2378]
#define sipNameNr_QMediaAvailabilityControl 2404
#define sipName_QMediaAvailabilityControl &sipStrings_QtMultimedia[2404]
#define sipNameNr_QMediaPlayer__MediaStatus 2430
#define sipName_QMediaPlayer__MediaStatus &sipStrings_QtMultimedia[2430]
#define sipNameNr_QMultimedia__EncodingMode 2456
#define sipName_QMultimedia__EncodingMode &sipStrings_QtMultimedia[2456]
#define sipNameNr_captureDestinationChanged 2482
#define sipName_captureDestinationChanged &sipStrings_QtMultimedia[2482]
#define sipNameNr_currentDigitalZoomChanged 2508
#define sipName_currentDigitalZoomChanged &sipStrings_QtMultimedia[2508]
#define sipNameNr_currentOpticalZoomChanged 2534
#define sipName_currentOpticalZoomChanged &sipStrings_QtMultimedia[2534]
#define sipNameNr_isFocusPointModeSupported 2560
#define sipName_isFocusPointModeSupported &sipStrings_QtMultimedia[2560]
#define sipNameNr_isParameterValueSupported 2586
#define sipName_isParameterValueSupported &sipStrings_QtMultimedia[2586]
#define sipNameNr_maximumDigitalZoomChanged 2612
#define sipName_maximumDigitalZoomChanged &sipStrings_QtMultimedia[2612]
#define sipNameNr_maximumOpticalZoomChanged 2638
#define sipName_maximumOpticalZoomChanged &sipStrings_QtMultimedia[2638]
#define sipNameNr_supportedAudioSampleRates 2664
#define sipName_supportedAudioSampleRates &sipStrings_QtMultimedia[2664]
#define sipNameNr_supportedCustomAudioRoles 2690
#define sipName_supportedCustomAudioRoles &sipStrings_QtMultimedia[2690]
#define sipNameNr_supportedIsoSensitivities 2716
#define sipName_supportedIsoSensitivities &sipStrings_QtMultimedia[2716]
#define sipNameNr_DeviceSettingDescription 2742
#define sipName_DeviceSettingDescription &sipStrings_QtMultimedia[2742]
#define sipNameNr_FlashSlowSyncRearCurtain 2767
#define sipName_FlashSlowSyncRearCurtain &sipStrings_QtMultimedia[2767]
#define sipNameNr_NotSupportedFeatureError 2792
#define sipName_NotSupportedFeatureError &sipStrings_QtMultimedia[2792]
#define sipNameNr_QAudioFormat__SampleType 2817
#define sipName_QAudioFormat__SampleType &sipStrings_QtMultimedia[2817]
#define sipNameNr_QCameraFocus__FocusModes 2842
#define sipName_QCameraFocus__FocusModes &sipStrings_QtMultimedia[2842]
#define sipNameNr_QVideoFrame__PixelFormat 2867
#define sipName_QVideoFrame__PixelFormat &sipStrings_QtMultimedia[2867]
#define sipNameNr_metaDataAvailableChanged 2892
#define sipName_metaDataAvailableChanged &sipStrings_QtMultimedia[2892]
#define sipNameNr_setNetworkConfigurations 2917
#define sipName_setNetworkConfigurations &sipStrings_QtMultimedia[2917]
#define sipNameNr_shutterSpeedRangeChanged 2942
#define sipName_shutterSpeedRangeChanged &sipStrings_QtMultimedia[2942]
#define sipNameNr_ConstantBitRateEncoding 2967
#define sipName_ConstantBitRateEncoding &sipStrings_QtMultimedia[2967]
#define sipNameNr_ConstantQualityEncoding 2991
#define sipName_ConstantQualityEncoding &sipStrings_QtMultimedia[2991]
#define sipNameNr_FocusPointFaceDetection 3015
#define sipName_FocusPointFaceDetection &sipStrings_QtMultimedia[3015]
#define sipNameNr_FormatNotSupportedError 3039
#define sipName_FormatNotSupportedError &sipStrings_QtMultimedia[3039]
#define sipNameNr_QCamera__FrameRateRange 3063
#define sipName_QCamera__FrameRateRange &sipStrings_QtMultimedia[3063]
#define sipNameNr_QCameraFocus__FocusMode 3087
#define sipName_QCameraFocus__FocusMode &sipStrings_QtMultimedia[3087]
#define sipNameNr_QCustomAudioRoleControl 3111
#define sipName_QCustomAudioRoleControl &sipStrings_QtMultimedia[3111]
#define sipNameNr_3135 3135
#define sipName_3135 &sipStrings_QtMultimedia[3135]
#define sipNameNr_3159 3159
#define sipName_3159 &sipStrings_QtMultimedia[3159]
#define sipNameNr_QMediaAudioProbeControl 3183
#define sipName_QMediaAudioProbeControl &sipStrings_QtMultimedia[3183]
#define sipNameNr_QMediaBindableInterface 3207
#define sipName_QMediaBindableInterface &sipStrings_QtMultimedia[3207]
#define sipNameNr_QMediaVideoProbeControl 3231
#define sipName_QMediaVideoProbeControl &sipStrings_QtMultimedia[3231]
#define sipNameNr_QRadioData__ProgramType 3255
#define sipName_QRadioData__ProgramType &sipStrings_QtMultimedia[3255]
#define sipNameNr_QRadioTuner__SearchMode 3279
#define sipName_QRadioTuner__SearchMode &sipStrings_QtMultimedia[3279]
#define sipNameNr_QRadioTuner__StereoMode 3303
#define sipName_QRadioTuner__StereoMode &sipStrings_QtMultimedia[3303]
#define sipNameNr_WhiteBalanceFluorescent 3327
#define sipName_WhiteBalanceFluorescent &sipStrings_QtMultimedia[3327]
#define sipNameNr_antennaConnectedChanged 3351
#define sipName_antennaConnectedChanged &sipStrings_QtMultimedia[3351]
#define sipNameNr_availableOutputsChanged 3375
#define sipName_availableOutputsChanged &sipStrings_QtMultimedia[3375]
#define sipNameNr_availablePlaybackRanges 3399
#define sipName_availablePlaybackRanges &sipStrings_QtMultimedia[3399]
#define sipNameNr_customFocusPointChanged 3423
#define sipName_customFocusPointChanged &sipStrings_QtMultimedia[3423]
#define sipNameNr_isExposureModeSupported 3447
#define sipName_isExposureModeSupported &sipStrings_QtMultimedia[3447]
#define sipNameNr_isMeteringModeSupported 3471
#define sipName_isMeteringModeSupported &sipStrings_QtMultimedia[3471]
#define sipNameNr_metaDataWritableChanged 3495
#define sipName_metaDataWritableChanged &sipStrings_QtMultimedia[3495]
#define sipNameNr_nativeResolutionChanged 3519
#define sipName_nativeResolutionChanged &sipStrings_QtMultimedia[3519]
#define sipNameNr_requestedIsoSensitivity 3543
#define sipName_requestedIsoSensitivity &sipStrings_QtMultimedia[3543]
#define sipNameNr_setEventFeedbackEnabled 3567
#define sipName_setEventFeedbackEnabled &sipStrings_QtMultimedia[3567]
#define sipNameNr_setExposureCompensation 3591
#define sipName_setExposureCompensation &sipStrings_QtMultimedia[3591]
#define sipNameNr_setManualIsoSensitivity 3615
#define sipName_setManualIsoSensitivity &sipStrings_QtMultimedia[3615]
#define sipNameNr_supportedFormatsChanged 3639
#define sipName_supportedFormatsChanged &sipStrings_QtMultimedia[3639]
#define sipNameNr_supportedParameterRange 3663
#define sipName_supportedParameterRange &sipStrings_QtMultimedia[3663]
#define sipNameNr_AverageBitRateEncoding 3687
#define sipName_AverageBitRateEncoding &sipStrings_QtMultimedia[3687]
#define sipNameNr_LogarithmicVolumeScale 3710
#define sipName_LogarithmicVolumeScale &sipStrings_QtMultimedia[3710]
#define sipNameNr_QCameraExposureControl 3733
#define sipName_QCameraExposureControl &sipStrings_QtMultimedia[3733]
#define sipNameNr_QCameraFeedbackControl 3756
#define sipName_QCameraFeedbackControl &sipStrings_QtMultimedia[3756]
#define sipNameNr_QCameraImageProcessing 3779
#define sipName_QCameraImageProcessing &sipStrings_QtMultimedia[3779]
#define sipNameNr_QMediaContainerControl 3802
#define sipName_QMediaContainerControl &sipStrings_QtMultimedia[3802]
#define sipNameNr_QMediaRecorder__Status 3825
#define sipName_QMediaRecorder__Status &sipStrings_QtMultimedia[3825]
#define sipNameNr_QMetaDataReaderControl 3848
#define sipName_QMetaDataReaderControl &sipStrings_QtMultimedia[3848]
#define sipNameNr_QMetaDataWriterControl 3871
#define sipName_QMetaDataWriterControl &sipStrings_QtMultimedia[3871]
#define sipNameNr_QVideoFrame__FieldType 3894
#define sipName_QVideoFrame__FieldType &sipStrings_QtMultimedia[3894]
#define sipNameNr_UnsupportedFormatError 3917
#define sipName_UnsupportedFormatError &sipStrings_QtMultimedia[3917]
#define sipNameNr_VoiceCommunicationRole 3940
#define sipName_VoiceCommunicationRole &sipStrings_QtMultimedia[3940]
#define sipNameNr_availableInputsChanged 3963
#define sipName_availableInputsChanged &sipStrings_QtMultimedia[3963]
#define sipNameNr_bufferAvailableChanged 3986
#define sipName_bufferAvailableChanged &sipStrings_QtMultimedia[3986]
#define sipNameNr_customAudioRoleChanged 4009
#define sipName_customAudioRoleChanged &sipStrings_QtMultimedia[4009]
#define sipNameNr_imageMetadataAvailable 4032
#define sipName_imageMetadataAvailable &sipStrings_QtMultimedia[4032]
#define sipNameNr_isCaptureModeSupported 4055
#define sipName_isCaptureModeSupported &sipStrings_QtMultimedia[4055]
#define sipNameNr_isColorFilterSupported 4078
#define sipName_isColorFilterSupported &sipStrings_QtMultimedia[4078]
#define sipNameNr_isEventFeedbackEnabled 4101
#define sipName_isEventFeedbackEnabled &sipStrings_QtMultimedia[4101]
#define sipNameNr_mediaAboutToBeInserted 4124
#define sipName_mediaAboutToBeInserted &sipStrings_QtMultimedia[4124]
#define sipNameNr_programTypeNameChanged 4147
#define sipName_programTypeNameChanged &sipStrings_QtMultimedia[4147]
#define sipNameNr_readyForCaptureChanged 4170
#define sipName_readyForCaptureChanged &sipStrings_QtMultimedia[4170]
#define sipNameNr_setViewfinderParameter 4193
#define sipName_setViewfinderParameter &sipStrings_QtMultimedia[4193]
#define sipNameNr_supportedBufferFormats 4216
#define sipName_supportedBufferFormats &sipStrings_QtMultimedia[4216]
#define sipNameNr_supportedChannelCounts 4239
#define sipName_supportedChannelCounts &sipStrings_QtMultimedia[4239]
#define sipNameNr_supportedShutterSpeeds 4262
#define sipName_supportedShutterSpeeds &sipStrings_QtMultimedia[4262]
#define sipNameNr_ColorFilterBlackboard 4285
#define sipName_ColorFilterBlackboard &sipStrings_QtMultimedia[4285]
#define sipNameNr_ColorFilterWhiteboard 4307
#define sipName_ColorFilterWhiteboard &sipStrings_QtMultimedia[4307]
#define sipNameNr_ExposureLargeAperture 4329
#define sipName_ExposureLargeAperture &sipStrings_QtMultimedia[4329]
#define sipNameNr_ExposureNightPortrait 4351
#define sipName_ExposureNightPortrait &sipStrings_QtMultimedia[4351]
#define sipNameNr_ExposureSmallAperture 4373
#define sipName_ExposureSmallAperture &sipStrings_QtMultimedia[4373]
#define sipNameNr_FocalLengthIn35mmFilm 4395
#define sipName_FocalLengthIn35mmFilm &sipStrings_QtMultimedia[4395]
#define sipNameNr_ImageEncodingSettings 4417
#define sipName_ImageEncodingSettings &sipStrings_QtMultimedia[4417]
#define sipNameNr_QAbstractVideoSurface 4439
#define sipName_QAbstractVideoSurface &sipStrings_QtMultimedia[4439]
#define sipNameNr_QAudioEncoderSettings 4461
#define sipName_QAudioEncoderSettings &sipStrings_QtMultimedia[4461]
#define sipNameNr_QCamera__CaptureModes 4483
#define sipName_QCamera__CaptureModes &sipStrings_QtMultimedia[4483]
#define sipNameNr_QImageEncoderSettings 4505
#define sipName_QImageEncoderSettings &sipStrings_QtMultimedia[4505]
#define sipNameNr_4527 4527
#define sipName_4527 &sipStrings_QtMultimedia[4527]
#define sipNameNr_QMediaPlaylist__Error 4549
#define sipName_QMediaPlaylist__Error &sipStrings_QtMultimedia[4549]
#define sipNameNr_QMediaRecorder__Error 4571
#define sipName_QMediaRecorder__Error &sipStrings_QtMultimedia[4571]
#define sipNameNr_QMediaRecorder__State 4593
#define sipName_QMediaRecorder__State &sipStrings_QtMultimedia[4593]
#define sipNameNr_QMediaRecorderControl 4615
#define sipName_QMediaRecorderControl &sipStrings_QtMultimedia[4615]
#define sipNameNr_QVideoEncoderSettings 4637
#define sipName_QVideoEncoderSettings &sipStrings_QtMultimedia[4637]
#define sipNameNr_QVideoRendererControl 4659
#define sipName_QVideoRendererControl &sipStrings_QtMultimedia[4659]
#define sipNameNr_VideoEncodingSettings 4681
#define sipName_VideoEncodingSettings &sipStrings_QtMultimedia[4681]
#define sipNameNr_actualLocationChanged 4703
#define sipName_actualLocationChanged &sipStrings_QtMultimedia[4703]
#define sipNameNr_audioAvailableChanged 4725
#define sipName_audioAvailableChanged &sipStrings_QtMultimedia[4725]
#define sipNameNr_audioCodecDescription 4747
#define sipName_audioCodecDescription &sipStrings_QtMultimedia[4747]
#define sipNameNr_audioInputDescription 4769
#define sipName_audioInputDescription &sipStrings_QtMultimedia[4769]
#define sipNameNr_focusPointModeChanged 4791
#define sipName_focusPointModeChanged &sipStrings_QtMultimedia[4791]
#define sipNameNr_imageCodecDescription 4813
#define sipName_imageCodecDescription &sipStrings_QtMultimedia[4813]
#define sipNameNr_isEventFeedbackLocked 4835
#define sipName_isEventFeedbackLocked &sipStrings_QtMultimedia[4835]
#define sipNameNr_isoSensitivityChanged 4857
#define sipName_isoSensitivityChanged &sipStrings_QtMultimedia[4857]
#define sipNameNr_loopsRemainingChanged 4879
#define sipName_loopsRemainingChanged &sipStrings_QtMultimedia[4879]
#define sipNameNr_mediaAboutToBeRemoved 4901
#define sipName_mediaAboutToBeRemoved &sipStrings_QtMultimedia[4901]
#define sipNameNr_notifyIntervalChanged 4923
#define sipName_notifyIntervalChanged &sipStrings_QtMultimedia[4923]
#define sipNameNr_parameterRangeChanged 4945
#define sipName_parameterRangeChanged &sipStrings_QtMultimedia[4945]
#define sipNameNr_requestedShutterSpeed 4967
#define sipName_requestedShutterSpeed &sipStrings_QtMultimedia[4967]
#define sipNameNr_requestedValueChanged 4989
#define sipName_requestedValueChanged &sipStrings_QtMultimedia[4989]
#define sipNameNr_selectedDeviceChanged 5011
#define sipName_selectedDeviceChanged &sipStrings_QtMultimedia[5011]
#define sipNameNr_setAutoIsoSensitivity 5033
#define sipName_setAutoIsoSensitivity &sipStrings_QtMultimedia[5033]
#define sipNameNr_setCaptureDestination 5055
#define sipName_setCaptureDestination &sipStrings_QtMultimedia[5055]
#define sipNameNr_setEventFeedbackSound 5077
#define sipName_setEventFeedbackSound &sipStrings_QtMultimedia[5077]
#define sipNameNr_setManualShutterSpeed 5099
#define sipName_setManualShutterSpeed &sipStrings_QtMultimedia[5099]
#define sipNameNr_setManualWhiteBalance 5121
#define sipName_setManualWhiteBalance &sipStrings_QtMultimedia[5121]
#define sipNameNr_setViewfinderSettings 5143
#define sipName_setViewfinderSettings &sipStrings_QtMultimedia[5143]
#define sipNameNr_signalStrengthChanged 5165
#define sipName_signalStrengthChanged &sipStrings_QtMultimedia[5165]
#define sipNameNr_supportedPixelFormats 5187
#define sipName_supportedPixelFormats &sipStrings_QtMultimedia[5187]
#define sipNameNr_videoAvailableChanged 5209
#define sipName_videoAvailableChanged &sipStrings_QtMultimedia[5209]
#define sipNameNr_videoCodecDescription 5231
#define sipName_videoCodecDescription &sipStrings_QtMultimedia[5231]
#define sipNameNr_BrightnessAdjustment 5253
#define sipName_BrightnessAdjustment &sipStrings_QtMultimedia[5253]
#define sipNameNr_ColorFilterGrayscale 5274
#define sipName_ColorFilterGrayscale &sipStrings_QtMultimedia[5274]
#define sipNameNr_ColorFilterPosterize 5295
#define sipName_ColorFilterPosterize &sipStrings_QtMultimedia[5295]
#define sipNameNr_ExposureCompensation 3594
#define sipName_ExposureCompensation &sipStrings_QtMultimedia[3594]
#define sipNameNr_FlashRedEyeReduction 5316
#define sipName_FlashRedEyeReduction &sipStrings_QtMultimedia[5316]
#define sipNameNr_IncorrectFormatError 5337
#define sipName_IncorrectFormatError &sipStrings_QtMultimedia[5337]
#define sipNameNr_QAbstractVideoBuffer 5358
#define sipName_QAbstractVideoBuffer &sipStrings_QtMultimedia[5358]
#define sipNameNr_QAbstractVideoFilter 5379
#define sipName_QAbstractVideoFilter &sipStrings_QtMultimedia[5379]
#define sipNameNr_QAudioDecoder__Error 5400
#define sipName_QAudioDecoder__Error &sipStrings_QtMultimedia[5400]
#define sipNameNr_QAudioDecoder__State 5421
#define sipName_QAudioDecoder__State &sipStrings_QtMultimedia[5421]
#define sipNameNr_QAudioDecoderControl 5442
#define sipName_QAudioDecoderControl &sipStrings_QtMultimedia[5442]
#define sipNameNr_QAudioFormat__Endian 5463
#define sipName_QAudioFormat__Endian &sipStrings_QtMultimedia[5463]
#define sipNameNr_QCamera__CaptureMode 5484
#define sipName_QCamera__CaptureMode &sipStrings_QtMultimedia[5484]
#define sipNameNr_QImageEncoderControl 5505
#define sipName_QImageEncoderControl &sipStrings_QtMultimedia[5505]
#define sipNameNr_5526 5526
#define sipName_5526 &sipStrings_QtMultimedia[5526]
#define sipNameNr_QMediaStreamsControl 5547
#define sipName_QMediaStreamsControl &sipStrings_QtMultimedia[5547]
#define sipNameNr_QSoundEffect__Status 5568
#define sipName_QSoundEffect__Status &sipStrings_QtMultimedia[5568]
#define sipNameNr_QVideoFilterRunnable 5589
#define sipName_QVideoFilterRunnable &sipStrings_QtMultimedia[5589]
#define sipNameNr_SaturationAdjustment 5610
#define sipName_SaturationAdjustment &sipStrings_QtMultimedia[5610]
#define sipNameNr_SharpeningAdjustment 5631
#define sipName_SharpeningAdjustment &sipStrings_QtMultimedia[5631]
#define sipNameNr_WhiteBalanceSunlight 5652
#define sipName_WhiteBalanceSunlight &sipStrings_QtMultimedia[5652]
#define sipNameNr_WhiteBalanceTungsten 5673
#define sipName_WhiteBalanceTungsten &sipStrings_QtMultimedia[5673]
#define sipNameNr_activeStreamsChanged 5694
#define sipName_activeStreamsChanged &sipStrings_QtMultimedia[5694]
#define sipNameNr_apertureRangeChanged 5715
#define sipName_apertureRangeChanged &sipStrings_QtMultimedia[5715]
#define sipNameNr_configurationChanged 5736
#define sipName_configurationChanged &sipStrings_QtMultimedia[5736]
#define sipNameNr_containerDescription 5757
#define sipName_containerDescription &sipStrings_QtMultimedia[5757]
#define sipNameNr_createFilterRunnable 5778
#define sipName_createFilterRunnable &sipStrings_QtMultimedia[5778]
#define sipNameNr_crossfadeTimeChanged 5799
#define sipName_crossfadeTimeChanged &sipStrings_QtMultimedia[5799]
#define sipNameNr_currentConfiguration 5820
#define sipName_currentConfiguration &sipStrings_QtMultimedia[5820]
#define sipNameNr_exposureCompensation 5841
#define sipName_exposureCompensation &sipStrings_QtMultimedia[5841]
#define sipNameNr_isCrossfadeSupported 5862
#define sipName_isCrossfadeSupported &sipStrings_QtMultimedia[5862]
#define sipNameNr_isFlashModeSupported 5883
#define sipName_isFlashModeSupported &sipStrings_QtMultimedia[5883]
#define sipNameNr_isFocusModeSupported 5904
#define sipName_isFocusModeSupported &sipStrings_QtMultimedia[5904]
#define sipNameNr_isParameterSupported 5925
#define sipName_isParameterSupported &sipStrings_QtMultimedia[5925]
#define sipNameNr_requestedDigitalZoom 5946
#define sipName_requestedDigitalZoom &sipStrings_QtMultimedia[5946]
#define sipNameNr_requestedOpticalZoom 5967
#define sipName_requestedOpticalZoom &sipStrings_QtMultimedia[5967]
#define sipNameNr_setScanLineDirection 5988
#define sipName_setScanLineDirection &sipStrings_QtMultimedia[5988]
#define sipNameNr_setSpotMeteringPoint 6009
#define sipName_setSpotMeteringPoint &sipStrings_QtMultimedia[6009]
#define sipNameNr_supportedAudioCodecs 6030
#define sipName_supportedAudioCodecs &sipStrings_QtMultimedia[6030]
#define sipNameNr_supportedImageCodecs 6051
#define sipName_supportedImageCodecs &sipStrings_QtMultimedia[6051]
#define sipNameNr_supportedResolutions 6072
#define sipName_supportedResolutions &sipStrings_QtMultimedia[6072]
#define sipNameNr_supportedSampleRates 6093
#define sipName_supportedSampleRates &sipStrings_QtMultimedia[6093]
#define sipNameNr_supportedSampleSizes 6114
#define sipName_supportedSampleSizes &sipStrings_QtMultimedia[6114]
#define sipNameNr_supportedSampleTypes 6135
#define sipName_supportedSampleTypes &sipStrings_QtMultimedia[6135]
#define sipNameNr_supportedVideoCodecs 6156
#define sipName_supportedVideoCodecs &sipStrings_QtMultimedia[6156]
#define sipNameNr_surfaceFormatChanged 6177
#define sipName_surfaceFormatChanged &sipStrings_QtMultimedia[6177]
#define sipNameNr_AutoFocusInProgress 6198
#define sipName_AutoFocusInProgress &sipStrings_QtMultimedia[6198]
#define sipNameNr_CaptureDestinations 168
#define sipName_CaptureDestinations &sipStrings_QtMultimedia[168]
#define sipNameNr_ChildrensProgrammes 6218
#define sipName_ChildrensProgrammes &sipStrings_QtMultimedia[6218]
#define sipNameNr_ColorFilterNegative 6238
#define sipName_ColorFilterNegative &sipStrings_QtMultimedia[6238]
#define sipNameNr_ColorFilterSolarize 6258
#define sipName_ColorFilterSolarize &sipStrings_QtMultimedia[6258]
#define sipNameNr_DenoisingAdjustment 6278
#define sipName_DenoisingAdjustment &sipStrings_QtMultimedia[6278]
#define sipNameNr_ExposureCandlelight 6298
#define sipName_ExposureCandlelight &sipStrings_QtMultimedia[6298]
#define sipNameNr_ExposureSteadyPhoto 6318
#define sipName_ExposureSteadyPhoto &sipStrings_QtMultimedia[6318]
#define sipNameNr_GPSProcessingMethod 6338
#define sipName_GPSProcessingMethod &sipStrings_QtMultimedia[6338]
#define sipNameNr_InvalidRequestError 6358
#define sipName_InvalidRequestError &sipStrings_QtMultimedia[6358]
#define sipNameNr_ProcessingParameter 85
#define sipName_ProcessingParameter &sipStrings_QtMultimedia[85]
#define sipNameNr_QAudio__VolumeScale 6378
#define sipName_QAudio__VolumeScale &sipStrings_QtMultimedia[6378]
#define sipNameNr_QCamera__LockStatus 6398
#define sipName_QCamera__LockStatus &sipStrings_QtMultimedia[6398]
#define sipNameNr_QCameraFlashControl 6418
#define sipName_QCameraFlashControl &sipStrings_QtMultimedia[6418]
#define sipNameNr_QCameraFocusControl 6438
#define sipName_QCameraFocusControl &sipStrings_QtMultimedia[6438]
#define sipNameNr_QCameraImageCapture 6458
#define sipName_QCameraImageCapture &sipStrings_QtMultimedia[6458]
#define sipNameNr_QCameraLocksControl 6478
#define sipName_QCameraLocksControl &sipStrings_QtMultimedia[6478]
#define sipNameNr_6498 6498
#define sipName_6498 &sipStrings_QtMultimedia[6498]
#define sipNameNr_QMediaPlayer__Error 6518
#define sipName_QMediaPlayer__Error &sipStrings_QtMultimedia[6518]
#define sipNameNr_QMediaPlayer__Flags 6538
#define sipName_QMediaPlayer__Flags &sipStrings_QtMultimedia[6538]
#define sipNameNr_QMediaPlayer__State 6558
#define sipName_QMediaPlayer__State &sipStrings_QtMultimedia[6558]
#define sipNameNr_QMediaPlayerControl 6578
#define sipName_QMediaPlayerControl &sipStrings_QtMultimedia[6578]
#define sipNameNr_QVideoSurfaceFormat 6598
#define sipName_QVideoSurfaceFormat &sipStrings_QtMultimedia[6598]
#define sipNameNr_QVideoWindowControl 6618
#define sipName_QVideoWindowControl &sipStrings_QtMultimedia[6618]
#define sipNameNr_RecordingInProgress 6638
#define sipName_RecordingInProgress &sipStrings_QtMultimedia[6638]
#define sipNameNr_ServiceMissingError 6658
#define sipName_ServiceMissingError &sipStrings_QtMultimedia[6658]
#define sipNameNr_UnspecifiedPosition 6678
#define sipName_UnspecifiedPosition &sipStrings_QtMultimedia[6678]
#define sipNameNr_ViewfinderParameter 34
#define sipName_ViewfinderParameter &sipStrings_QtMultimedia[34]
#define sipNameNr_activeOutputChanged 6698
#define sipName_activeOutputChanged &sipStrings_QtMultimedia[6698]
#define sipNameNr_advancedToNextMedia 6718
#define sipName_advancedToNextMedia &sipStrings_QtMultimedia[6718]
#define sipNameNr_availabilityChanged 6738
#define sipName_availabilityChanged &sipStrings_QtMultimedia[6738]
#define sipNameNr_bufferFormatChanged 6758
#define sipName_bufferFormatChanged &sipStrings_QtMultimedia[6758]
#define sipNameNr_bufferStatusChanged 6778
#define sipName_bufferStatusChanged &sipStrings_QtMultimedia[6778]
#define sipNameNr_currentIndexChanged 6798
#define sipName_currentIndexChanged &sipStrings_QtMultimedia[6798]
#define sipNameNr_currentMediaChanged 6818
#define sipName_currentMediaChanged &sipStrings_QtMultimedia[6818]
#define sipNameNr_defaultOutputDevice 6838
#define sipName_defaultOutputDevice &sipStrings_QtMultimedia[6838]
#define sipNameNr_isMetaDataAvailable 6858
#define sipName_isMetaDataAvailable &sipStrings_QtMultimedia[6858]
#define sipNameNr_playbackModeChanged 6878
#define sipName_playbackModeChanged &sipStrings_QtMultimedia[6878]
#define sipNameNr_playbackRateChanged 6898
#define sipName_playbackRateChanged &sipStrings_QtMultimedia[6898]
#define sipNameNr_removePropertyWatch 6918
#define sipName_removePropertyWatch &sipStrings_QtMultimedia[6918]
#define sipNameNr_setAutoShutterSpeed 6938
#define sipName_setAutoShutterSpeed &sipStrings_QtMultimedia[6938]
#define sipNameNr_setCustomFocusPoint 6958
#define sipName_setCustomFocusPoint &sipStrings_QtMultimedia[6958]
#define sipNameNr_setEncodingSettings 6978
#define sipName_setEncodingSettings &sipStrings_QtMultimedia[6978]
#define sipNameNr_setMaximumFrameRate 6998
#define sipName_setMaximumFrameRate &sipStrings_QtMultimedia[6998]
#define sipNameNr_setMinimumFrameRate 7018
#define sipName_setMinimumFrameRate &sipStrings_QtMultimedia[7018]
#define sipNameNr_setNativeResolution 7038
#define sipName_setNativeResolution &sipStrings_QtMultimedia[7038]
#define sipNameNr_setPixelAspectRatio 7058
#define sipName_setPixelAspectRatio &sipStrings_QtMultimedia[7058]
#define sipNameNr_setWhiteBalanceMode 7078
#define sipName_setWhiteBalanceMode &sipStrings_QtMultimedia[7078]
#define sipNameNr_shutterSpeedChanged 7098
#define sipName_shutterSpeedChanged &sipStrings_QtMultimedia[7098]
#define sipNameNr_stereoStatusChanged 7118
#define sipName_stereoStatusChanged &sipStrings_QtMultimedia[7118]
#define sipNameNr_supportedAudioRoles 7138
#define sipName_supportedAudioRoles &sipStrings_QtMultimedia[7138]
#define sipNameNr_supportedByteOrders 7158
#define sipName_supportedByteOrders &sipStrings_QtMultimedia[7158]
#define sipNameNr_supportedContainers 7178
#define sipName_supportedContainers &sipStrings_QtMultimedia[7178]
#define sipNameNr_supportedFrameRates 7198
#define sipName_supportedFrameRates &sipStrings_QtMultimedia[7198]
#define sipNameNr_viewfinderParameter 7218
#define sipName_viewfinderParameter &sipStrings_QtMultimedia[7218]
#define sipNameNr_AvailabilityStatus 860
#define sipName_AvailabilityStatus &sipStrings_QtMultimedia[860]
#define sipNameNr_CameraManufacturer 7238
#define sipName_CameraManufacturer &sipStrings_QtMultimedia[7238]
#define sipNameNr_CaptureDestination 250
#define sipName_CaptureDestination &sipStrings_QtMultimedia[250]
#define sipNameNr_ContrastAdjustment 7257
#define sipName_ContrastAdjustment &sipStrings_QtMultimedia[7257]
#define sipNameNr_ContributingArtist 7276
#define sipName_ContributingArtist &sipStrings_QtMultimedia[7276]
#define sipNameNr_DecibelVolumeScale 7295
#define sipName_DecibelVolumeScale &sipStrings_QtMultimedia[7295]
#define sipNameNr_ExposureModeVendor 7314
#define sipName_ExposureModeVendor &sipStrings_QtMultimedia[7314]
#define sipNameNr_GPSAreaInformation 7333
#define sipName_GPSAreaInformation &sipStrings_QtMultimedia[7333]
#define sipNameNr_GPSImgDirectionRef 7352
#define sipName_GPSImgDirectionRef &sipStrings_QtMultimedia[7352]
#define sipNameNr_PropertyChangeType 395
#define sipName_PropertyChangeType &sipStrings_QtMultimedia[395]
#define sipNameNr_PyQt5_QtMultimedia 7371
#define sipName_PyQt5_QtMultimedia &sipStrings_QtMultimedia[7371]
#define sipNameNr_QCamera__LockTypes 7390
#define sipName_QCamera__LockTypes &sipStrings_QtMultimedia[7390]
#define sipNameNr_QCameraInfoControl 7409
#define sipName_QCameraInfoControl &sipStrings_QtMultimedia[7409]
#define sipNameNr_QCameraZoomControl 7428
#define sipName_QCameraZoomControl &sipStrings_QtMultimedia[7428]
#define sipNameNr_QGraphicsVideoItem 7447
#define sipName_QGraphicsVideoItem &sipStrings_QtMultimedia[7447]
#define sipNameNr_7466 7466
#define sipName_7466 &sipStrings_QtMultimedia[7466]
#define sipNameNr_QMediaPlayer__Flag 7485
#define sipName_QMediaPlayer__Flag &sipStrings_QtMultimedia[7485]
#define sipNameNr_QMediaTimeInterval 7504
#define sipName_QMediaTimeInterval &sipStrings_QtMultimedia[7504]
#define sipNameNr_QRadioTuner__Error 7523
#define sipName_QRadioTuner__Error &sipStrings_QtMultimedia[7523]
#define sipNameNr_QRadioTuner__State 7542
#define sipName_QRadioTuner__State &sipStrings_QtMultimedia[7542]
#define sipNameNr_QRadioTunerControl 7561
#define sipName_QRadioTunerControl &sipStrings_QtMultimedia[7561]
#define sipNameNr_QSoundEffect__Loop 7580
#define sipName_QSoundEffect__Loop &sipStrings_QtMultimedia[7580]
#define sipNameNr_RatingOrganization 7599
#define sipName_RatingOrganization &sipStrings_QtMultimedia[7599]
#define sipNameNr_SearchGetStationId 7618
#define sipName_SearchGetStationId &sipStrings_QtMultimedia[7618]
#define sipNameNr_SingleImageCapture 7637
#define sipName_SingleImageCapture &sipStrings_QtMultimedia[7637]
#define sipNameNr_SoftRhythmAndBlues 7656
#define sipName_SoftRhythmAndBlues &sipStrings_QtMultimedia[7656]
#define sipNameNr_UnknownMediaStatus 7675
#define sipName_UnknownMediaStatus &sipStrings_QtMultimedia[7675]
#define sipNameNr_ViewfinderSettings 2066
#define sipName_ViewfinderSettings &sipStrings_QtMultimedia[2066]
#define sipNameNr_WhiteBalanceCloudy 7694
#define sipName_WhiteBalanceCloudy &sipStrings_QtMultimedia[7694]
#define sipNameNr_WhiteBalanceManual 7713
#define sipName_WhiteBalanceManual &sipStrings_QtMultimedia[7713]
#define sipNameNr_WhiteBalancePreset 7732
#define sipName_WhiteBalancePreset &sipStrings_QtMultimedia[7732]
#define sipNameNr_WhiteBalanceSunset 7751
#define sipName_WhiteBalanceSunset &sipStrings_QtMultimedia[7751]
#define sipNameNr_WhiteBalanceVendor 7770
#define sipName_WhiteBalanceVendor &sipStrings_QtMultimedia[7770]
#define sipNameNr_activeInputChanged 7789
#define sipName_activeInputChanged &sipStrings_QtMultimedia[7789]
#define sipNameNr_actualValueChanged 7808
#define sipName_actualValueChanged &sipStrings_QtMultimedia[7808]
#define sipNameNr_captureDestination 7827
#define sipName_captureDestination &sipStrings_QtMultimedia[7827]
#define sipNameNr_captureModeChanged 7846
#define sipName_captureModeChanged &sipStrings_QtMultimedia[7846]
#define sipNameNr_currentDigitalZoom 7865
#define sipName_currentDigitalZoom &sipStrings_QtMultimedia[7865]
#define sipNameNr_currentOpticalZoom 7884
#define sipName_currentOpticalZoom &sipStrings_QtMultimedia[7884]
#define sipNameNr_defaultInputDevice 7903
#define sipName_defaultInputDevice &sipStrings_QtMultimedia[7903]
#define sipNameNr_digitalZoomChanged 7922
#define sipName_digitalZoomChanged &sipStrings_QtMultimedia[7922]
#define sipNameNr_isAntennaConnected 7941
#define sipName_isAntennaConnected &sipStrings_QtMultimedia[7941]
#define sipNameNr_isMetaDataWritable 7960
#define sipName_isMetaDataWritable &sipStrings_QtMultimedia[7960]
#define sipNameNr_manualWhiteBalance 7979
#define sipName_manualWhiteBalance &sipStrings_QtMultimedia[7979]
#define sipNameNr_maximumDigitalZoom 7998
#define sipName_maximumDigitalZoom &sipStrings_QtMultimedia[7998]
#define sipNameNr_maximumOpticalZoom 8017
#define sipName_maximumOpticalZoom &sipStrings_QtMultimedia[8017]
#define sipNameNr_mediaStatusChanged 8036
#define sipName_mediaStatusChanged &sipStrings_QtMultimedia[8036]
#define sipNameNr_opticalZoomChanged 8055
#define sipName_opticalZoomChanged &sipStrings_QtMultimedia[8055]
#define sipNameNr_programTypeChanged 8074
#define sipName_programTypeChanged &sipStrings_QtMultimedia[8074]
#define sipNameNr_resetEventFeedback 8093
#define sipName_resetEventFeedback &sipStrings_QtMultimedia[8093]
#define sipNameNr_setAspectRatioMode 8112
#define sipName_setAspectRatioMode &sipStrings_QtMultimedia[8112]
#define sipNameNr_setContainerFormat 8131
#define sipName_setContainerFormat &sipStrings_QtMultimedia[8131]
#define sipNameNr_setCustomAudioRole 8150
#define sipName_setCustomAudioRole &sipStrings_QtMultimedia[8150]
#define sipNameNr_setEncodingOptions 8169
#define sipName_setEncodingOptions &sipStrings_QtMultimedia[8169]
#define sipNameNr_setSharpeningLevel 8188
#define sipName_setSharpeningLevel &sipStrings_QtMultimedia[8188]
#define sipNameNr_setYCbCrColorSpace 8207
#define sipName_setYCbCrColorSpace &sipStrings_QtMultimedia[8207]
#define sipNameNr_stationNameChanged 8226
#define sipName_stationNameChanged &sipStrings_QtMultimedia[8226]
#define sipNameNr_supportedApertures 8245
#define sipName_supportedApertures &sipStrings_QtMultimedia[8245]
#define sipNameNr_supportedMimeTypes 8264
#define sipName_supportedMimeTypes &sipStrings_QtMultimedia[8264]
#define sipNameNr_viewfinderSettings 8283
#define sipName_viewfinderSettings &sipStrings_QtMultimedia[8283]
#define sipNameNr_AccessDeniedError 8302
#define sipName_AccessDeniedError &sipStrings_QtMultimedia[8302]
#define sipNameNr_AccessibilityRole 8320
#define sipName_AccessibilityRole &sipStrings_QtMultimedia[8320]
#define sipNameNr_CaptureStillImage 8338
#define sipName_CaptureStillImage &sipStrings_QtMultimedia[8338]
#define sipNameNr_CaptureViewfinder 8356
#define sipName_CaptureViewfinder &sipStrings_QtMultimedia[8356]
#define sipNameNr_ColorFilterVendor 8374
#define sipName_ColorFilterVendor &sipStrings_QtMultimedia[8374]
#define sipNameNr_CurrentItemInLoop 8392
#define sipName_CurrentItemInLoop &sipStrings_QtMultimedia[8392]
#define sipNameNr_DateTimeDigitized 8410
#define sipName_DateTimeDigitized &sipStrings_QtMultimedia[8410]
#define sipNameNr_ExposureBacklight 8428
#define sipName_ExposureBacklight &sipStrings_QtMultimedia[8428]
#define sipNameNr_ExposureBiasValue 8446
#define sipName_ExposureBiasValue &sipStrings_QtMultimedia[8446]
#define sipNameNr_ExposureFireworks 8464
#define sipName_ExposureFireworks &sipStrings_QtMultimedia[8464]
#define sipNameNr_ExposureLandscape 8482
#define sipName_ExposureLandscape &sipStrings_QtMultimedia[8482]
#define sipNameNr_ExposureParameter 129
#define sipName_ExposureParameter &sipStrings_QtMultimedia[129]
#define sipNameNr_ExposureSpotlight 8500
#define sipName_ExposureSpotlight &sipStrings_QtMultimedia[8500]
#define sipNameNr_ExtendedParameter 8518
#define sipName_ExtendedParameter &sipStrings_QtMultimedia[8518]
#define sipNameNr_FlashCompensation 8536
#define sipName_FlashCompensation &sipStrings_QtMultimedia[8536]
#define sipNameNr_LinearVolumeScale 8554
#define sipName_LinearVolumeScale &sipStrings_QtMultimedia[8554]
#define sipNameNr_LockTemporaryLost 8572
#define sipName_LockTemporaryLost &sipStrings_QtMultimedia[8572]
#define sipNameNr_ProbablySupported 8590
#define sipName_ProbablySupported &sipStrings_QtMultimedia[8590]
#define sipNameNr_QAudioRoleControl 8608
#define sipName_QAudioRoleControl &sipStrings_QtMultimedia[8608]
#define sipNameNr_QCamera__LockType 8626
#define sipName_QCamera__LockType &sipStrings_QtMultimedia[8626]
#define sipNameNr_QCamera__Position 8644
#define sipName_QCamera__Position &sipStrings_QtMultimedia[8644]
#define sipNameNr_QRadioData__Error 8662
#define sipName_QRadioData__Error &sipStrings_QtMultimedia[8662]
#define sipNameNr_QRadioDataControl 8680
#define sipName_QRadioDataControl &sipStrings_QtMultimedia[8680]
#define sipNameNr_QRadioTuner__Band 8698
#define sipName_QRadioTuner__Band &sipStrings_QtMultimedia[8698]
#define sipNameNr_SpotMeteringPoint 6012
#define sipName_SpotMeteringPoint &sipStrings_QtMultimedia[6012]
#define sipNameNr_UnavailableStatus 8716
#define sipName_UnavailableStatus &sipStrings_QtMultimedia[8716]
#define sipNameNr_ViewfinderStarted 8734
#define sipName_ViewfinderStarted &sipStrings_QtMultimedia[8734]
#define sipNameNr_ViewfinderStopped 8752
#define sipName_ViewfinderStopped &sipStrings_QtMultimedia[8752]
#define sipNameNr_WhiteBalanceFlash 8770
#define sipName_WhiteBalanceFlash &sipStrings_QtMultimedia[8770]
#define sipNameNr_WhiteBalanceShade 8788
#define sipName_WhiteBalanceShade &sipStrings_QtMultimedia[8788]
#define sipNameNr_audioBufferProbed 8806
#define sipName_audioBufferProbed &sipStrings_QtMultimedia[8806]
#define sipNameNr_audioInputChanged 8824
#define sipName_audioInputChanged &sipStrings_QtMultimedia[8824]
#define sipNameNr_availableMetaData 8842
#define sipName_availableMetaData &sipStrings_QtMultimedia[8842]
#define sipNameNr_brightnessChanged 8860
#define sipName_brightnessChanged &sipStrings_QtMultimedia[8860]
#define sipNameNr_cameraOrientation 8878
#define sipName_cameraOrientation &sipStrings_QtMultimedia[8878]
#define sipNameNr_canChangeProperty 8896
#define sipName_canChangeProperty &sipStrings_QtMultimedia[8896]
#define sipNameNr_canonicalResource 8914
#define sipName_canonicalResource &sipStrings_QtMultimedia[8914]
#define sipNameNr_defaultAudioInput 8932
#define sipName_defaultAudioInput &sipStrings_QtMultimedia[8932]
#define sipNameNr_deviceDescription 8950
#define sipName_deviceDescription &sipStrings_QtMultimedia[8950]
#define sipNameNr_durationForFrames 8968
#define sipName_durationForFrames &sipStrings_QtMultimedia[8968]
#define sipNameNr_focusZonesChanged 8986
#define sipName_focusZonesChanged &sipStrings_QtMultimedia[8986]
#define sipNameNr_framesForDuration 9004
#define sipName_framesForDuration &sipStrings_QtMultimedia[9004]
#define sipNameNr_fullScreenChanged 9022
#define sipName_fullScreenChanged &sipStrings_QtMultimedia[9022]
#define sipNameNr_isFormatSupported 9040
#define sipName_isFormatSupported &sipStrings_QtMultimedia[9040]
#define sipNameNr_isReadyForCapture 9058
#define sipName_isReadyForCapture &sipStrings_QtMultimedia[9058]
#define sipNameNr_lockStatusChanged 9076
#define sipName_lockStatusChanged &sipStrings_QtMultimedia[9076]
#define sipNameNr_nativeSizeChanged 9094
#define sipName_nativeSizeChanged &sipStrings_QtMultimedia[9094]
#define sipNameNr_outputDescription 9112
#define sipName_outputDescription &sipStrings_QtMultimedia[9112]
#define sipNameNr_requestedAperture 9130
#define sipName_requestedAperture &sipStrings_QtMultimedia[9130]
#define sipNameNr_saturationChanged 9148
#define sipName_saturationChanged &sipStrings_QtMultimedia[9148]
#define sipNameNr_scanLineDirection 9166
#define sipName_scanLineDirection &sipStrings_QtMultimedia[9166]
#define sipNameNr_searchAllStations 9184
#define sipName_searchAllStations &sipStrings_QtMultimedia[9184]
#define sipNameNr_setConfigurations 9202
#define sipName_setConfigurations &sipStrings_QtMultimedia[9202]
#define sipNameNr_setDenoisingLevel 9220
#define sipName_setDenoisingLevel &sipStrings_QtMultimedia[9220]
#define sipNameNr_setEncodingOption 9238
#define sipName_setEncodingOption &sipStrings_QtMultimedia[9238]
#define sipNameNr_setFocusPointMode 9256
#define sipName_setFocusPointMode &sipStrings_QtMultimedia[9256]
#define sipNameNr_setManualAperture 9274
#define sipName_setManualAperture &sipStrings_QtMultimedia[9274]
#define sipNameNr_setNotifyInterval 9292
#define sipName_setNotifyInterval &sipStrings_QtMultimedia[9292]
#define sipNameNr_setOutputLocation 9310
#define sipName_setOutputLocation &sipStrings_QtMultimedia[9310]
#define sipNameNr_setSelectedDevice 9328
#define sipName_setSelectedDevice &sipStrings_QtMultimedia[9328]
#define sipNameNr_setSourceFilename 9346
#define sipName_setSourceFilename &sipStrings_QtMultimedia[9346]
#define sipNameNr_sip_simplewrapper 9364
#define sipName_sip_simplewrapper &sipStrings_QtMultimedia[9364]
#define sipNameNr_spotMeteringPoint 9382
#define sipName_spotMeteringPoint &sipStrings_QtMultimedia[9382]
#define sipNameNr_ColorFilterSepia 9400
#define sipName_ColorFilterSepia &sipStrings_QtMultimedia[9400]
#define sipNameNr_ColorTemperature 9417
#define sipName_ColorTemperature &sipStrings_QtMultimedia[9417]
#define sipNameNr_CoverArtUrlLarge 9434
#define sipName_CoverArtUrlLarge &sipStrings_QtMultimedia[9434]
#define sipNameNr_CoverArtUrlSmall 9451
#define sipName_CoverArtUrlSmall &sipStrings_QtMultimedia[9451]
#define sipNameNr_CubicVolumeScale 9468
#define sipName_CubicVolumeScale &sipStrings_QtMultimedia[9468]
#define sipNameNr_DateTimeOriginal 9485
#define sipName_DateTimeOriginal &sipStrings_QtMultimedia[9485]
#define sipNameNr_DigitalZoomRatio 9502
#define sipName_DigitalZoomRatio &sipStrings_QtMultimedia[9502]
#define sipNameNr_ExposurePortrait 9519
#define sipName_ExposurePortrait &sipStrings_QtMultimedia[9519]
#define sipNameNr_FinalizingStatus 9536
#define sipName_FinalizingStatus &sipStrings_QtMultimedia[9536]
#define sipNameNr_FocusPointCenter 9553
#define sipName_FocusPointCenter &sipStrings_QtMultimedia[9553]
#define sipNameNr_FocusPointCustom 9570
#define sipName_FocusPointCustom &sipStrings_QtMultimedia[9570]
#define sipNameNr_Format_CameraRaw 9587
#define sipName_Format_CameraRaw &sipStrings_QtMultimedia[9587]
#define sipNameNr_InterruptedState 9604
#define sipName_InterruptedState &sipStrings_QtMultimedia[9604]
#define sipNameNr_LockChangeReason 2335
#define sipName_LockChangeReason &sipStrings_QtMultimedia[2335]
#define sipNameNr_LockWhiteBalance 9621
#define sipName_LockWhiteBalance &sipStrings_QtMultimedia[9621]
#define sipNameNr_MaximumFrameRate 7001
#define sipName_MaximumFrameRate &sipStrings_QtMultimedia[7001]
#define sipNameNr_MinimumFrameRate 7021
#define sipName_MinimumFrameRate &sipStrings_QtMultimedia[7021]
#define sipNameNr_NotificationRole 9638
#define sipName_NotificationRole &sipStrings_QtMultimedia[9638]
#define sipNameNr_PixelAspectRatio 7061
#define sipName_PixelAspectRatio &sipStrings_QtMultimedia[7061]
#define sipNameNr_PreferredService 9655
#define sipName_PreferredService &sipStrings_QtMultimedia[9655]
#define sipNameNr_ProgressiveFrame 9672
#define sipName_ProgressiveFrame &sipStrings_QtMultimedia[9672]
#define sipNameNr_QAudioDeviceInfo 9689
#define sipName_QAudioDeviceInfo &sipStrings_QtMultimedia[9689]
#define sipNameNr_QCameraFocusZone 9706
#define sipName_QCameraFocusZone &sipStrings_QtMultimedia[9706]
#define sipNameNr_RecordingStarted 9723
#define sipName_RecordingStarted &sipStrings_QtMultimedia[9723]
#define sipNameNr_RecordingStopped 9740
#define sipName_RecordingStopped &sipStrings_QtMultimedia[9740]
#define sipNameNr_SceneCaptureType 9757
#define sipName_SceneCaptureType &sipStrings_QtMultimedia[9757]
#define sipNameNr_SeriousClassical 9774
#define sipName_SeriousClassical &sipStrings_QtMultimedia[9774]
#define sipNameNr_SonificationRole 9791
#define sipName_SonificationRole &sipStrings_QtMultimedia[9791]
#define sipNameNr_SubPictureStream 9808
#define sipName_SubPictureStream &sipStrings_QtMultimedia[9808]
#define sipNameNr_WhiteBalanceAuto 9825
#define sipName_WhiteBalanceAuto &sipStrings_QtMultimedia[9825]
#define sipNameNr_WhiteBalanceMode 212
#define sipName_WhiteBalanceMode &sipStrings_QtMultimedia[212]
#define sipNameNr_XvShmImageHandle 9842
#define sipName_XvShmImageHandle &sipStrings_QtMultimedia[9842]
#define sipNameNr_addPropertyWatch 9859
#define sipName_addPropertyWatch &sipStrings_QtMultimedia[9859]
#define sipNameNr_audioRoleChanged 9876
#define sipName_audioRoleChanged &sipStrings_QtMultimedia[9876]
#define sipNameNr_availableCameras 9893
#define sipName_availableCameras &sipStrings_QtMultimedia[9893]
#define sipNameNr_availableDevices 9910
#define sipName_availableDevices &sipStrings_QtMultimedia[9910]
#define sipNameNr_availableOutputs 9927
#define sipName_availableOutputs &sipStrings_QtMultimedia[9927]
#define sipNameNr_bytesForDuration 9944
#define sipName_bytesForDuration &sipStrings_QtMultimedia[9944]
#define sipNameNr_canonicalRequest 9961
#define sipName_canonicalRequest &sipStrings_QtMultimedia[9961]
#define sipNameNr_codecDescription 9978
#define sipName_codecDescription &sipStrings_QtMultimedia[9978]
#define sipNameNr_customFocusPoint 9995
#define sipName_customFocusPoint &sipStrings_QtMultimedia[9995]
#define sipNameNr_disconnectNotify 10012
#define sipName_disconnectNotify &sipStrings_QtMultimedia[10012]
#define sipNameNr_durationForBytes 10029
#define sipName_durationForBytes &sipStrings_QtMultimedia[10029]
#define sipNameNr_encodingSettings 10046
#define sipName_encodingSettings &sipStrings_QtMultimedia[10046]
#define sipNameNr_focusModeChanged 10063
#define sipName_focusModeChanged &sipStrings_QtMultimedia[10063]
#define sipNameNr_frequencyChanged 10080
#define sipName_frequencyChanged &sipStrings_QtMultimedia[10080]
#define sipNameNr_inputDescription 10097
#define sipName_inputDescription &sipStrings_QtMultimedia[10097]
#define sipNameNr_isAudioAvailable 10114
#define sipName_isAudioAvailable &sipStrings_QtMultimedia[10114]
#define sipNameNr_isVideoAvailable 10131
#define sipName_isVideoAvailable &sipStrings_QtMultimedia[10131]
#define sipNameNr_loopCountChanged 10148
#define sipName_loopCountChanged &sipStrings_QtMultimedia[10148]
#define sipNameNr_maximumFrameRate 10165
#define sipName_maximumFrameRate &sipStrings_QtMultimedia[10165]
#define sipNameNr_minimumFrameRate 10182
#define sipName_minimumFrameRate &sipStrings_QtMultimedia[10182]
#define sipNameNr_nativeResolution 10199
#define sipName_nativeResolution &sipStrings_QtMultimedia[10199]
#define sipNameNr_nextMediaChanged 10216
#define sipName_nextMediaChanged &sipStrings_QtMultimedia[10216]
#define sipNameNr_pixelAspectRatio 10233
#define sipName_pixelAspectRatio &sipStrings_QtMultimedia[10233]
#define sipNameNr_radioTextChanged 10250
#define sipName_radioTextChanged &sipStrings_QtMultimedia[10250]
#define sipNameNr_searchingChanged 10267
#define sipName_searchingChanged &sipStrings_QtMultimedia[10267]
#define sipNameNr_setAudioSettings 10284
#define sipName_setAudioSettings &sipStrings_QtMultimedia[10284]
#define sipNameNr_setCrossfadeTime 10301
#define sipName_setCrossfadeTime &sipStrings_QtMultimedia[10301]
#define sipNameNr_setImageSettings 10318
#define sipName_setImageSettings &sipStrings_QtMultimedia[10318]
#define sipNameNr_setVideoSettings 10335
#define sipName_setVideoSettings &sipStrings_QtMultimedia[10335]
#define sipNameNr_stationIdChanged 10352
#define sipName_stationIdChanged &sipStrings_QtMultimedia[10352]
#define sipNameNr_videoFrameProbed 10369
#define sipName_videoFrameProbed &sipStrings_QtMultimedia[10369]
#define sipNameNr_whiteBalanceMode 10386
#define sipName_whiteBalanceMode &sipStrings_QtMultimedia[10386]
#define sipNameNr_AutoFocusFailed 10403
#define sipName_AutoFocusFailed &sipStrings_QtMultimedia[10403]
#define sipNameNr_AutoFocusLocked 10419
#define sipName_AutoFocusLocked &sipStrings_QtMultimedia[10419]
#define sipNameNr_CaptureToBuffer 10435
#define sipName_CaptureToBuffer &sipStrings_QtMultimedia[10435]
#define sipNameNr_ColorFilterAqua 10451
#define sipName_ColorFilterAqua &sipStrings_QtMultimedia[10451]
#define sipNameNr_ColorFilterNone 10467
#define sipName_ColorFilterNone &sipStrings_QtMultimedia[10467]
#define sipNameNr_ContinuousFocus 10483
#define sipName_ContinuousFocus &sipStrings_QtMultimedia[10483]
#define sipNameNr_CoreImageHandle 10499
#define sipName_CoreImageHandle &sipStrings_QtMultimedia[10499]
#define sipNameNr_CurrentItemOnce 10515
#define sipName_CurrentItemOnce &sipStrings_QtMultimedia[10515]
#define sipNameNr_EncodingQuality 1619
#define sipName_EncodingQuality &sipStrings_QtMultimedia[1619]
#define sipNameNr_ExposureBarcode 10531
#define sipName_ExposureBarcode &sipStrings_QtMultimedia[10531]
#define sipNameNr_ExposureProgram 10547
#define sipName_ExposureProgram &sipStrings_QtMultimedia[10547]
#define sipNameNr_ExposureTheatre 10563
#define sipName_ExposureTheatre &sipStrings_QtMultimedia[10563]
#define sipNameNr_FlashVideoLight 10579
#define sipName_FlashVideoLight &sipStrings_QtMultimedia[10579]
#define sipNameNr_FocusZoneStatus 535
#define sipName_FocusZoneStatus &sipStrings_QtMultimedia[535]
#define sipNameNr_Format_AdobeDng 10595
#define sipName_Format_AdobeDng &sipStrings_QtMultimedia[10595]
#define sipNameNr_GLTextureHandle 10611
#define sipName_GLTextureHandle &sipStrings_QtMultimedia[10611]
#define sipNameNr_GPSImgDirection 10627
#define sipName_GPSImgDirection &sipStrings_QtMultimedia[10627]
#define sipNameNr_HyperfocalFocus 10643
#define sipName_HyperfocalFocus &sipStrings_QtMultimedia[10643]
#define sipNameNr_ISOSpeedRatings 10659
#define sipName_ISOSpeedRatings &sipStrings_QtMultimedia[10659]
#define sipNameNr_InterlacedFrame 10675
#define sipName_InterlacedFrame &sipStrings_QtMultimedia[10675]
#define sipNameNr_MeteringAverage 10691
#define sipName_MeteringAverage &sipStrings_QtMultimedia[10691]
#define sipNameNr_OutOfRangeError 10707
#define sipName_OutOfRangeError &sipStrings_QtMultimedia[10707]
#define sipNameNr_OutOfSpaceError 10723
#define sipName_OutOfSpaceError &sipStrings_QtMultimedia[10723]
#define sipNameNr_QCamera__Status 10739
#define sipName_QCamera__Status &sipStrings_QtMultimedia[10739]
#define sipNameNr_QCameraExposure 10755
#define sipName_QCameraExposure &sipStrings_QtMultimedia[10755]
#define sipNameNr_QMediaTimeRange 10771
#define sipName_QMediaTimeRange &sipStrings_QtMultimedia[10771]
#define sipNameNr_RecordingStatus 10787
#define sipName_RecordingStatus &sipStrings_QtMultimedia[10787]
#define sipNameNr_SubjectDistance 10803
#define sipName_SubjectDistance &sipStrings_QtMultimedia[10803]
#define sipNameNr_SupportEstimate 1648
#define sipName_SupportEstimate &sipStrings_QtMultimedia[1648]
#define sipNameNr_TwoPassEncoding 10819
#define sipName_TwoPassEncoding &sipStrings_QtMultimedia[10819]
#define sipNameNr_UnloadingStatus 10835
#define sipName_UnloadingStatus &sipStrings_QtMultimedia[10835]
#define sipNameNr_VeryHighQuality 10851
#define sipName_VeryHighQuality &sipStrings_QtMultimedia[10851]
#define sipNameNr_YCbCrColorSpace 290
#define sipName_YCbCrColorSpace &sipStrings_QtMultimedia[290]
#define sipNameNr_YCbCr_Undefined 10867
#define sipName_YCbCr_Undefined &sipStrings_QtMultimedia[10867]
#define sipNameNr_apertureChanged 10883
#define sipName_apertureChanged &sipStrings_QtMultimedia[10883]
#define sipNameNr_aspectRatioMode 10899
#define sipName_aspectRatioMode &sipStrings_QtMultimedia[10899]
#define sipNameNr_availableInputs 10915
#define sipName_availableInputs &sipStrings_QtMultimedia[10915]
#define sipNameNr_bufferAvailable 10931
#define sipName_bufferAvailable &sipStrings_QtMultimedia[10931]
#define sipNameNr_categoryChanged 10947
#define sipName_categoryChanged &sipStrings_QtMultimedia[10947]
#define sipNameNr_containerFormat 10963
#define sipName_containerFormat &sipStrings_QtMultimedia[10963]
#define sipNameNr_contrastChanged 10979
#define sipName_contrastChanged &sipStrings_QtMultimedia[10979]
#define sipNameNr_customAudioRole 10995
#define sipName_customAudioRole &sipStrings_QtMultimedia[10995]
#define sipNameNr_durationChanged 11011
#define sipName_durationChanged &sipStrings_QtMultimedia[11011]
#define sipNameNr_encodingOptions 11027
#define sipName_encodingOptions &sipStrings_QtMultimedia[11027]
#define sipNameNr_imageProcessing 11043
#define sipName_imageProcessing &sipStrings_QtMultimedia[11043]
#define sipNameNr_isBandSupported 11059
#define sipName_isBandSupported &sipStrings_QtMultimedia[11059]
#define sipNameNr_metaDataChanged 11075
#define sipName_metaDataChanged &sipStrings_QtMultimedia[11075]
#define sipNameNr_positionChanged 11091
#define sipName_positionChanged &sipStrings_QtMultimedia[11091]
#define sipNameNr_preferredFormat 11107
#define sipName_preferredFormat &sipStrings_QtMultimedia[11107]
#define sipNameNr_programTypeName 11123
#define sipName_programTypeName &sipStrings_QtMultimedia[11123]
#define sipNameNr_removeTimeRange 11139
#define sipName_removeTimeRange &sipStrings_QtMultimedia[11139]
#define sipNameNr_seekableChanged 11155
#define sipName_seekableChanged &sipStrings_QtMultimedia[11155]
#define sipNameNr_setActiveOutput 11171
#define sipName_setActiveOutput &sipStrings_QtMultimedia[11171]
#define sipNameNr_setAudioBitRate 11187
#define sipName_setAudioBitRate &sipStrings_QtMultimedia[11187]
#define sipNameNr_setAutoAperture 11203
#define sipName_setAutoAperture &sipStrings_QtMultimedia[11203]
#define sipNameNr_setBufferFormat 11219
#define sipName_setBufferFormat &sipStrings_QtMultimedia[11219]
#define sipNameNr_setChannelCount 11235
#define sipName_setChannelCount &sipStrings_QtMultimedia[11235]
#define sipNameNr_setCurrentIndex 11251
#define sipName_setCurrentIndex &sipStrings_QtMultimedia[11251]
#define sipNameNr_setEncodingMode 11267
#define sipName_setEncodingMode &sipStrings_QtMultimedia[11267]
#define sipNameNr_setExposureMode 11283
#define sipName_setExposureMode &sipStrings_QtMultimedia[11283]
#define sipNameNr_setMeteringMode 11299
#define sipName_setMeteringMode &sipStrings_QtMultimedia[11299]
#define sipNameNr_setPlaybackMode 11315
#define sipName_setPlaybackMode &sipStrings_QtMultimedia[11315]
#define sipNameNr_setPlaybackRate 11331
#define sipName_setPlaybackRate &sipStrings_QtMultimedia[11331]
#define sipNameNr_setSourceDevice 11347
#define sipName_setSourceDevice &sipStrings_QtMultimedia[11347]
#define sipNameNr_setVideoBitRate 11363
#define sipName_setVideoBitRate &sipStrings_QtMultimedia[11363]
#define sipNameNr_sharpeningLevel 11379
#define sipName_sharpeningLevel &sipStrings_QtMultimedia[11379]
#define sipNameNr_supportedCodecs 11395
#define sipName_supportedCodecs &sipStrings_QtMultimedia[11395]
#define sipNameNr_writableChanged 11411
#define sipName_writableChanged &sipStrings_QtMultimedia[11411]
#define sipNameNr_yCbCrColorSpace 11427
#define sipName_yCbCrColorSpace &sipStrings_QtMultimedia[11427]
#define sipNameNr_BufferingMedia 11443
#define sipName_BufferingMedia &sipStrings_QtMultimedia[11443]
#define sipNameNr_CurrentAffairs 11458
#define sipName_CurrentAffairs &sipStrings_QtMultimedia[11458]
#define sipNameNr_EGLImageHandle 11473
#define sipName_EGLImageHandle &sipStrings_QtMultimedia[11473]
#define sipNameNr_ExposureAction 11488
#define sipName_ExposureAction &sipStrings_QtMultimedia[11488]
#define sipNameNr_ExposureManual 11503
#define sipName_ExposureManual &sipStrings_QtMultimedia[11503]
#define sipNameNr_ExposureSports 11518
#define sipName_ExposureSports &sipStrings_QtMultimedia[11518]
#define sipNameNr_ExposureSunset 11533
#define sipName_ExposureSunset &sipStrings_QtMultimedia[11533]
#define sipNameNr_FocusPointAuto 11548
#define sipName_FocusPointAuto &sipStrings_QtMultimedia[11548]
#define sipNameNr_FocusPointMode 1533
#define sipName_FocusPointMode &sipStrings_QtMultimedia[1533]
#define sipNameNr_Format_AYUV444 11563
#define sipName_Format_AYUV444 &sipStrings_QtMultimedia[11563]
#define sipNameNr_Format_Invalid 11578
#define sipName_Format_Invalid &sipStrings_QtMultimedia[11578]
#define sipNameNr_Format_YUV420P 11593
#define sipName_Format_YUV420P &sipStrings_QtMultimedia[11593]
#define sipNameNr_Format_YUV422P 11608
#define sipName_Format_YUV422P &sipStrings_QtMultimedia[11608]
#define sipNameNr_FrameRateRange 3072
#define sipName_FrameRateRange &sipStrings_QtMultimedia[3072]
#define sipNameNr_LightClassical 11623
#define sipName_LightClassical &sipStrings_QtMultimedia[11623]
#define sipNameNr_MaybeSupported 11638
#define sipName_MaybeSupported &sipStrings_QtMultimedia[11638]
#define sipNameNr_MeteringMatrix 11653
#define sipName_MeteringMatrix &sipStrings_QtMultimedia[11653]
#define sipNameNr_ParentalRating 11668
#define sipName_ParentalRating &sipStrings_QtMultimedia[11668]
#define sipNameNr_QAudioRecorder 11683
#define sipName_QAudioRecorder &sipStrings_QtMultimedia[11683]
#define sipNameNr_QCamera__Error 11698
#define sipName_QCamera__Error &sipStrings_QtMultimedia[11698]
#define sipNameNr_QCamera__State 11713
#define sipName_QCamera__State &sipStrings_QtMultimedia[11713]
#define sipNameNr_QCameraControl 11728
#define sipName_QCameraControl &sipStrings_QtMultimedia[11728]
#define sipNameNr_11743 11743
#define sipName_11743 &sipStrings_QtMultimedia[11743]
#define sipNameNr_QMediaMetaData 11758
#define sipName_QMediaMetaData &sipStrings_QtMultimedia[11758]
#define sipNameNr_QMediaPlaylist 11773
#define sipName_QMediaPlaylist &sipStrings_QtMultimedia[11773]
#define sipNameNr_QMediaRecorder 11788
#define sipName_QMediaRecorder &sipStrings_QtMultimedia[11788]
#define sipNameNr_QMediaResource 11803
#define sipName_QMediaResource &sipStrings_QtMultimedia[11803]
#define sipNameNr_RecordingState 11818
#define sipName_RecordingState &sipStrings_QtMultimedia[11818]
#define sipNameNr_ReligiousMusic 11833
#define sipName_ReligiousMusic &sipStrings_QtMultimedia[11833]
#define sipNameNr_RhythmAndBlues 7660
#define sipName_RhythmAndBlues &sipStrings_QtMultimedia[7660]
#define sipNameNr_ServiceMissing 11848
#define sipName_ServiceMissing &sipStrings_QtMultimedia[11848]
#define sipNameNr_StartingStatus 11863
#define sipName_StartingStatus &sipStrings_QtMultimedia[11863]
#define sipNameNr_StoppingStatus 11878
#define sipName_StoppingStatus &sipStrings_QtMultimedia[11878]
#define sipNameNr_StreamPlayback 11893
#define sipName_StreamPlayback &sipStrings_QtMultimedia[11893]
#define sipNameNr_SuspendedState 11908
#define sipName_SuspendedState &sipStrings_QtMultimedia[11908]
#define sipNameNr_ThumbnailImage 11923
#define sipName_ThumbnailImage &sipStrings_QtMultimedia[11923]
#define sipNameNr_UnloadedStatus 11938
#define sipName_UnloadedStatus &sipStrings_QtMultimedia[11938]
#define sipNameNr_VeryLowQuality 11953
#define sipName_VeryLowQuality &sipStrings_QtMultimedia[11953]
#define sipNameNr_VideoFrameRate 11968
#define sipName_VideoFrameRate &sipStrings_QtMultimedia[11968]
#define sipNameNr_YCbCr_xvYCC601 11983
#define sipName_YCbCr_xvYCC601 &sipStrings_QtMultimedia[11983]
#define sipNameNr_YCbCr_xvYCC709 11998
#define sipName_YCbCr_xvYCC709 &sipStrings_QtMultimedia[11998]
#define sipNameNr_actualLocation 12013
#define sipName_actualLocation &sipStrings_QtMultimedia[12013]
#define sipNameNr_bytesForFrames 12028
#define sipName_bytesForFrames &sipStrings_QtMultimedia[12028]
#define sipNameNr_cameraPosition 12043
#define sipName_cameraPosition &sipStrings_QtMultimedia[12043]
#define sipNameNr_denoisingLevel 12058
#define sipName_denoisingLevel &sipStrings_QtMultimedia[12058]
#define sipNameNr_devicesChanged 12073
#define sipName_devicesChanged &sipStrings_QtMultimedia[12073]
#define sipNameNr_encodingOption 12088
#define sipName_encodingOption &sipStrings_QtMultimedia[12088]
#define sipNameNr_focusPointMode 12103
#define sipName_focusPointMode &sipStrings_QtMultimedia[12103]
#define sipNameNr_framesForBytes 12118
#define sipName_framesForBytes &sipStrings_QtMultimedia[12118]
#define sipNameNr_frequencyRange 12133
#define sipName_frequencyRange &sipStrings_QtMultimedia[12133]
#define sipNameNr_imageAvailable 12148
#define sipName_imageAvailable &sipStrings_QtMultimedia[12148]
#define sipNameNr_isoSensitivity 12163
#define sipName_isoSensitivity &sipStrings_QtMultimedia[12163]
#define sipNameNr_loopsRemaining 12178
#define sipName_loopsRemaining &sipStrings_QtMultimedia[12178]
#define sipNameNr_notifyInterval 12193
#define sipName_notifyInterval &sipStrings_QtMultimedia[12193]
#define sipNameNr_outputLocation 12208
#define sipName_outputLocation &sipStrings_QtMultimedia[12208]
#define sipNameNr_playingChanged 12223
#define sipName_playingChanged &sipStrings_QtMultimedia[12223]
#define sipNameNr_processedUSecs 12238
#define sipName_processedUSecs &sipStrings_QtMultimedia[12238]
#define sipNameNr_releaseControl 12253
#define sipName_releaseControl &sipStrings_QtMultimedia[12253]
#define sipNameNr_removeInterval 12268
#define sipName_removeInterval &sipStrings_QtMultimedia[12268]
#define sipNameNr_requestControl 12283
#define sipName_requestControl &sipStrings_QtMultimedia[12283]
#define sipNameNr_requestedLocks 12298
#define sipName_requestedLocks &sipStrings_QtMultimedia[12298]
#define sipNameNr_requestedValue 12313
#define sipName_requestedValue &sipStrings_QtMultimedia[12313]
#define sipNameNr_searchBackward 12328
#define sipName_searchBackward &sipStrings_QtMultimedia[12328]
#define sipNameNr_selectedDevice 12343
#define sipName_selectedDevice &sipStrings_QtMultimedia[12343]
#define sipNameNr_setActiveInput 12358
#define sipName_setActiveInput &sipStrings_QtMultimedia[12358]
#define sipNameNr_setAudioFormat 12373
#define sipName_setAudioFormat &sipStrings_QtMultimedia[12373]
#define sipNameNr_setCaptureMode 12388
#define sipName_setCaptureMode &sipStrings_QtMultimedia[12388]
#define sipNameNr_setColorFilter 12403
#define sipName_setColorFilter &sipStrings_QtMultimedia[12403]
#define sipNameNr_setDisplayRect 12418
#define sipName_setDisplayRect &sipStrings_QtMultimedia[12418]
#define sipNameNr_setMediaObject 12433
#define sipName_setMediaObject &sipStrings_QtMultimedia[12433]
#define sipNameNr_setPixelFormat 12448
#define sipName_setPixelFormat &sipStrings_QtMultimedia[12448]
#define sipNameNr_setVideoOutput 12463
#define sipName_setVideoOutput &sipStrings_QtMultimedia[12463]
#define sipNameNr_signalStrength 12478
#define sipName_signalStrength &sipStrings_QtMultimedia[12478]
#define sipNameNr_sourceFilename 12493
#define sipName_sourceFilename &sipStrings_QtMultimedia[12493]
#define sipNameNr_streamsChanged 12508
#define sipName_streamsChanged &sipStrings_QtMultimedia[12508]
#define sipNameNr_supportedLocks 12523
#define sipName_supportedLocks &sipStrings_QtMultimedia[12523]
#define sipNameNr_BufferedMedia 12538
#define sipName_BufferedMedia &sipStrings_QtMultimedia[12538]
#define sipNameNr_CaptureToFile 12552
#define sipName_CaptureToFile &sipStrings_QtMultimedia[12552]
#define sipNameNr_ChapterNumber 12566
#define sipName_ChapterNumber &sipStrings_QtMultimedia[12566]
#define sipNameNr_CoverArtImage 12580
#define sipName_CoverArtImage &sipStrings_QtMultimedia[12580]
#define sipNameNr_DecodingState 12594
#define sipName_DecodingState &sipStrings_QtMultimedia[12594]
#define sipNameNr_EasyListening 12608
#define sipName_EasyListening &sipStrings_QtMultimedia[12608]
#define sipNameNr_ExposureBeach 12622
#define sipName_ExposureBeach &sipStrings_QtMultimedia[12622]
#define sipNameNr_ExposureNight 12636
#define sipName_ExposureNight &sipStrings_QtMultimedia[12636]
#define sipNameNr_ExposureParty 12650
#define sipName_ExposureParty &sipStrings_QtMultimedia[12650]
#define sipNameNr_Format_ABGR32 12664
#define sipName_Format_ABGR32 &sipStrings_QtMultimedia[12664]
#define sipNameNr_Format_ARGB32 12678
#define sipName_Format_ARGB32 &sipStrings_QtMultimedia[12678]
#define sipNameNr_Format_BGR555 12692
#define sipName_Format_BGR555 &sipStrings_QtMultimedia[12692]
#define sipNameNr_Format_BGR565 12706
#define sipName_Format_BGR565 &sipStrings_QtMultimedia[12706]
#define sipNameNr_Format_BGRA32 12720
#define sipName_Format_BGRA32 &sipStrings_QtMultimedia[12720]
#define sipNameNr_Format_RGB555 12734
#define sipName_Format_RGB555 &sipStrings_QtMultimedia[12734]
#define sipNameNr_Format_RGB565 12748
#define sipName_Format_RGB565 &sipStrings_QtMultimedia[12748]
#define sipNameNr_Format_YUV444 12762
#define sipName_Format_YUV444 &sipStrings_QtMultimedia[12762]
#define sipNameNr_GPSSatellites 12776
#define sipName_GPSSatellites &sipStrings_QtMultimedia[12776]
#define sipNameNr_ImageCaptured 12790
#define sipName_ImageCaptured &sipStrings_QtMultimedia[12790]
#define sipNameNr_InfinityFocus 12804
#define sipName_InfinityFocus &sipStrings_QtMultimedia[12804]
#define sipNameNr_LeadPerformer 12818
#define sipName_LeadPerformer &sipStrings_QtMultimedia[12818]
#define sipNameNr_LoadingStatus 12832
#define sipName_LoadingStatus &sipStrings_QtMultimedia[12832]
#define sipNameNr_NationalMusic 12846
#define sipName_NationalMusic &sipStrings_QtMultimedia[12846]
#define sipNameNr_NormalQuality 12860
#define sipName_NormalQuality &sipStrings_QtMultimedia[12860]
#define sipNameNr_NotReadyError 12874
#define sipName_NotReadyError &sipStrings_QtMultimedia[12874]
#define sipNameNr_QAudio__Error 12888
#define sipName_QAudio__Error &sipStrings_QtMultimedia[12888]
#define sipNameNr_QAudio__State 12902
#define sipName_QAudio__State &sipStrings_QtMultimedia[12902]
#define sipNameNr_QAudioDecoder 12916
#define sipName_QAudioDecoder &sipStrings_QtMultimedia[12916]
#define sipNameNr_QMediaContent 12930
#define sipName_QMediaContent &sipStrings_QtMultimedia[12930]
#define sipNameNr_QMediaControl 12944
#define sipName_QMediaControl &sipStrings_QtMultimedia[12944]
#define sipNameNr_QMediaService 12958
#define sipName_QMediaService &sipStrings_QtMultimedia[12958]
#define sipNameNr_QPixmapHandle 12972
#define sipName_QPixmapHandle &sipStrings_QtMultimedia[12972]
#define sipNameNr_ReligiousTalk 12986
#define sipName_ReligiousTalk &sipStrings_QtMultimedia[12986]
#define sipNameNr_ResourceError 13000
#define sipName_ResourceError &sipStrings_QtMultimedia[13000]
#define sipNameNr_SocialAffairs 13014
#define sipName_SocialAffairs &sipStrings_QtMultimedia[13014]
#define sipNameNr_StandbyStatus 13028
#define sipName_StandbyStatus &sipStrings_QtMultimedia[13028]
#define sipNameNr_UnderrunError 13042
#define sipName_UnderrunError &sipStrings_QtMultimedia[13042]
#define sipNameNr_UnknownStream 13056
#define sipName_UnknownStream &sipStrings_QtMultimedia[13056]
#define sipNameNr_UnloadedState 13070
#define sipName_UnloadedState &sipStrings_QtMultimedia[13070]
#define sipNameNr_UserParameter 13084
#define sipName_UserParameter &sipStrings_QtMultimedia[13084]
#define sipNameNr_activeChanged 13098
#define sipName_activeChanged &sipStrings_QtMultimedia[13098]
#define sipNameNr_applySettings 13112
#define sipName_applySettings &sipStrings_QtMultimedia[13112]
#define sipNameNr_audioSettings 13126
#define sipName_audioSettings &sipStrings_QtMultimedia[13126]
#define sipNameNr_bytesPerFrame 13140
#define sipName_bytesPerFrame &sipStrings_QtMultimedia[13140]
#define sipNameNr_cancelCapture 13154
#define sipName_cancelCapture &sipStrings_QtMultimedia[13154]
#define sipNameNr_connectNotify 10015
#define sipName_connectNotify &sipStrings_QtMultimedia[10015]
#define sipNameNr_convertVolume 13168
#define sipName_convertVolume &sipStrings_QtMultimedia[13168]
#define sipNameNr_crossfadeTime 13182
#define sipName_crossfadeTime &sipStrings_QtMultimedia[13182]
#define sipNameNr_defaultCamera 13196
#define sipName_defaultCamera &sipStrings_QtMultimedia[13196]
#define sipNameNr_defaultDevice 13210
#define sipName_defaultDevice &sipStrings_QtMultimedia[13210]
#define sipNameNr_defaultOutput 13224
#define sipName_defaultOutput &sipStrings_QtMultimedia[13224]
#define sipNameNr_errorOccurred 13238
#define sipName_errorOccurred &sipStrings_QtMultimedia[13238]
#define sipNameNr_formatChanged 13252
#define sipName_formatChanged &sipStrings_QtMultimedia[13252]
#define sipNameNr_frequencyStep 13266
#define sipName_frequencyStep &sipStrings_QtMultimedia[13266]
#define sipNameNr_imageCaptured 13280
#define sipName_imageCaptured &sipStrings_QtMultimedia[13280]
#define sipNameNr_imageSettings 13294
#define sipName_imageSettings &sipStrings_QtMultimedia[13294]
#define sipNameNr_loadedChanged 13308
#define sipName_loadedChanged &sipStrings_QtMultimedia[13308]
#define sipNameNr_mediaInserted 13322
#define sipName_mediaInserted &sipStrings_QtMultimedia[13322]
#define sipNameNr_nearestFormat 13336
#define sipName_nearestFormat &sipStrings_QtMultimedia[13336]
#define sipNameNr_previousIndex 13350
#define sipName_previousIndex &sipStrings_QtMultimedia[13350]
#define sipNameNr_propertyNames 13364
#define sipName_propertyNames &sipStrings_QtMultimedia[13364]
#define sipNameNr_searchAndLock 13378
#define sipName_searchAndLock &sipStrings_QtMultimedia[13378]
#define sipNameNr_searchForward 13392
#define sipName_searchForward &sipStrings_QtMultimedia[13392]
#define sipNameNr_setAudioCodec 13406
#define sipName_setAudioCodec &sipStrings_QtMultimedia[13406]
#define sipNameNr_setAudioInput 13420
#define sipName_setAudioInput &sipStrings_QtMultimedia[13420]
#define sipNameNr_setBrightness 13434
#define sipName_setBrightness &sipStrings_QtMultimedia[13434]
#define sipNameNr_setBufferSize 13448
#define sipName_setBufferSize &sipStrings_QtMultimedia[13448]
#define sipNameNr_setFullScreen 13462
#define sipName_setFullScreen &sipStrings_QtMultimedia[13462]
#define sipNameNr_setResolution 13476
#define sipName_setResolution &sipStrings_QtMultimedia[13476]
#define sipNameNr_setSampleRate 13490
#define sipName_setSampleRate &sipStrings_QtMultimedia[13490]
#define sipNameNr_setSampleSize 13504
#define sipName_setSampleSize &sipStrings_QtMultimedia[13504]
#define sipNameNr_setSampleType 13518
#define sipName_setSampleType &sipStrings_QtMultimedia[13518]
#define sipNameNr_setSaturation 13532
#define sipName_setSaturation &sipStrings_QtMultimedia[13532]
#define sipNameNr_setStereoMode 13546
#define sipName_setStereoMode &sipStrings_QtMultimedia[13546]
#define sipNameNr_setVideoCodec 13560
#define sipName_setVideoCodec &sipStrings_QtMultimedia[13560]
#define sipNameNr_setViewfinder 13574
#define sipName_setViewfinder &sipStrings_QtMultimedia[13574]
#define sipNameNr_sourceChanged 13588
#define sipName_sourceChanged &sipStrings_QtMultimedia[13588]
#define sipNameNr_statusChanged 13602
#define sipName_statusChanged &sipStrings_QtMultimedia[13602]
#define sipNameNr_surfaceFormat 13616
#define sipName_surfaceFormat &sipStrings_QtMultimedia[13616]
#define sipNameNr_videoSettings 13630
#define sipName_videoSettings &sipStrings_QtMultimedia[13630]
#define sipNameNr_volumeChanged 13644
#define sipName_volumeChanged &sipStrings_QtMultimedia[13644]
#define sipNameNr_ActiveStatus 13658
#define sipName_ActiveStatus &sipStrings_QtMultimedia[13658]
#define sipNameNr_AudioBitRate 11190
#define sipName_AudioBitRate &sipStrings_QtMultimedia[11190]
#define sipNameNr_AverageLevel 13671
#define sipName_AverageLevel &sipStrings_QtMultimedia[13671]
#define sipNameNr_CaptureModes 4492
#define sipName_CaptureModes &sipStrings_QtMultimedia[4492]
#define sipNameNr_CaptureVideo 13684
#define sipName_CaptureVideo &sipStrings_QtMultimedia[13684]
#define sipNameNr_ChannelCount 11238
#define sipName_ChannelCount &sipStrings_QtMultimedia[11238]
#define sipNameNr_CountryMusic 13697
#define sipName_CountryMusic &sipStrings_QtMultimedia[13697]
#define sipNameNr_EncodingMode 2469
#define sipName_EncodingMode &sipStrings_QtMultimedia[2469]
#define sipNameNr_ExposureAuto 13710
#define sipName_ExposureAuto &sipStrings_QtMultimedia[13710]
#define sipNameNr_ExposureMode 1299
#define sipName_ExposureMode &sipStrings_QtMultimedia[1299]
#define sipNameNr_ExposureSnow 13723
#define sipName_ExposureSnow &sipStrings_QtMultimedia[13723]
#define sipNameNr_ExposureTime 13736
#define sipName_ExposureTime &sipStrings_QtMultimedia[13736]
#define sipNameNr_Format_BGR24 13749
#define sipName_Format_BGR24 &sipStrings_QtMultimedia[13749]
#define sipNameNr_Format_BGR32 13762
#define sipName_Format_BGR32 &sipStrings_QtMultimedia[13762]
#define sipNameNr_Format_RGB24 13775
#define sipName_Format_RGB24 &sipStrings_QtMultimedia[13775]
#define sipNameNr_Format_RGB32 13788
#define sipName_Format_RGB32 &sipStrings_QtMultimedia[13788]
#define sipNameNr_GPSLongitude 13801
#define sipName_GPSLongitude &sipStrings_QtMultimedia[13801]
#define sipNameNr_GPSTimeStamp 13814
#define sipName_GPSTimeStamp &sipStrings_QtMultimedia[13814]
#define sipNameNr_InvalidMedia 13827
#define sipName_InvalidMedia &sipStrings_QtMultimedia[13827]
#define sipNameNr_LittleEndian 13840
#define sipName_LittleEndian &sipStrings_QtMultimedia[13840]
#define sipNameNr_LoadedStatus 13853
#define sipName_LoadedStatus &sipStrings_QtMultimedia[13853]
#define sipNameNr_LoadingMedia 13866
#define sipName_LoadingMedia &sipStrings_QtMultimedia[13866]
#define sipNameNr_LockAcquired 13879
#define sipName_LockAcquired &sipStrings_QtMultimedia[13879]
#define sipNameNr_LockExposure 13892
#define sipName_LockExposure &sipStrings_QtMultimedia[13892]
#define sipNameNr_MeteringMode 1329
#define sipName_MeteringMode &sipStrings_QtMultimedia[1329]
#define sipNameNr_MeteringSpot 13905
#define sipName_MeteringSpot &sipStrings_QtMultimedia[13905]
#define sipNameNr_NetworkError 13918
#define sipName_NetworkError &sipStrings_QtMultimedia[13918]
#define sipNameNr_NotSupported 13931
#define sipName_NotSupported &sipStrings_QtMultimedia[13931]
#define sipNameNr_PausedStatus 13944
#define sipName_PausedStatus &sipStrings_QtMultimedia[13944]
#define sipNameNr_PlaybackMode 1593
#define sipName_PlaybackMode &sipStrings_QtMultimedia[1593]
#define sipNameNr_PlayingState 13957
#define sipName_PlayingState &sipStrings_QtMultimedia[13957]
#define sipNameNr_QAudio__Mode 13970
#define sipName_QAudio__Mode &sipStrings_QtMultimedia[13970]
#define sipNameNr_QAudio__Role 13983
#define sipName_QAudio__Role &sipStrings_QtMultimedia[13983]
#define sipNameNr_QAudioBuffer 13996
#define sipName_QAudioBuffer &sipStrings_QtMultimedia[13996]
#define sipNameNr_QAudioFormat 14009
#define sipName_QAudioFormat &sipStrings_QtMultimedia[14009]
#define sipNameNr_QAudioOutput 14022
#define sipName_QAudioOutput &sipStrings_QtMultimedia[14022]
#define sipNameNr_QCameraFocus 14035
#define sipName_QCameraFocus &sipStrings_QtMultimedia[14035]
#define sipNameNr_QMediaObject 14048
#define sipName_QMediaObject &sipStrings_QtMultimedia[14048]
#define sipNameNr_QMediaPlayer 14061
#define sipName_QMediaPlayer &sipStrings_QtMultimedia[14061]
#define sipNameNr_QSound__Loop 14074
#define sipName_QSound__Loop &sipStrings_QtMultimedia[14074]
#define sipNameNr_QSoundEffect 14087
#define sipName_QSoundEffect &sipStrings_QtMultimedia[14087]
#define sipNameNr_QVideoWidget 14100
#define sipName_QVideoWidget &sipStrings_QtMultimedia[14100]
#define sipNameNr_RingtoneRole 14113
#define sipName_RingtoneRole &sipStrings_QtMultimedia[14113]
#define sipNameNr_ShutterSpeed 4976
#define sipName_ShutterSpeed &sipStrings_QtMultimedia[4976]
#define sipNameNr_StalledMedia 14126
#define sipName_StalledMedia &sipStrings_QtMultimedia[14126]
#define sipNameNr_StoppedError 14139
#define sipName_StoppedError &sipStrings_QtMultimedia[14139]
#define sipNameNr_StoppedState 14152
#define sipName_StoppedState &sipStrings_QtMultimedia[14152]
#define sipNameNr_VideoBitRate 11366
#define sipName_VideoBitRate &sipStrings_QtMultimedia[11366]
#define sipNameNr_VideoSurface 4448
#define sipName_VideoSurface &sipStrings_QtMultimedia[4448]
#define sipNameNr_WhiteBalance 5130
#define sipName_WhiteBalance &sipStrings_QtMultimedia[5130]
#define sipNameNr_activeOutput 14165
#define sipName_activeOutput &sipStrings_QtMultimedia[14165]
#define sipNameNr_addTimeRange 14178
#define sipName_addTimeRange &sipStrings_QtMultimedia[14178]
#define sipNameNr_audioBitRate 14191
#define sipName_audioBitRate &sipStrings_QtMultimedia[14191]
#define sipNameNr_availability 14204
#define sipName_availability &sipStrings_QtMultimedia[14204]
#define sipNameNr_bufferFormat 14217
#define sipName_bufferFormat &sipStrings_QtMultimedia[14217]
#define sipNameNr_bufferStatus 14230
#define sipName_bufferStatus &sipStrings_QtMultimedia[14230]
#define sipNameNr_bytesPerLine 14243
#define sipName_bytesPerLine &sipStrings_QtMultimedia[14243]
#define sipNameNr_cancelSearch 14256
#define sipName_cancelSearch &sipStrings_QtMultimedia[14256]
#define sipNameNr_canonicalUrl 14269
#define sipName_canonicalUrl &sipStrings_QtMultimedia[14269]
#define sipNameNr_channelCount 14282
#define sipName_channelCount &sipStrings_QtMultimedia[14282]
#define sipNameNr_currentIndex 14295
#define sipName_currentIndex &sipStrings_QtMultimedia[14295]
#define sipNameNr_currentMedia 14308
#define sipName_currentMedia &sipStrings_QtMultimedia[14308]
#define sipNameNr_defaultInput 14321
#define sipName_defaultInput &sipStrings_QtMultimedia[14321]
#define sipNameNr_earliestTime 14334
#define sipName_earliestTime &sipStrings_QtMultimedia[14334]
#define sipNameNr_elapsedUSecs 14347
#define sipName_elapsedUSecs &sipStrings_QtMultimedia[14347]
#define sipNameNr_encodingMode 14360
#define sipName_encodingMode &sipStrings_QtMultimedia[14360]
#define sipNameNr_exposureMode 14373
#define sipName_exposureMode &sipStrings_QtMultimedia[14373]
#define sipNameNr_imageExposed 14386
#define sipName_imageExposed &sipStrings_QtMultimedia[14386]
#define sipNameNr_isContinuous 14399
#define sipName_isContinuous &sipStrings_QtMultimedia[14399]
#define sipNameNr_isFlashReady 14412
#define sipName_isFlashReady &sipStrings_QtMultimedia[14412]
#define sipNameNr_isFullScreen 14425
#define sipName_isFullScreen &sipStrings_QtMultimedia[14425]
#define sipNameNr_mediaChanged 14438
#define sipName_mediaChanged &sipStrings_QtMultimedia[14438]
#define sipNameNr_mediaRemoved 14451
#define sipName_mediaRemoved &sipStrings_QtMultimedia[14451]
#define sipNameNr_meteringMode 14464
#define sipName_meteringMode &sipStrings_QtMultimedia[14464]
#define sipNameNr_mutedChanged 14477
#define sipName_mutedChanged &sipStrings_QtMultimedia[14477]
#define sipNameNr_playbackMode 14490
#define sipName_playbackMode &sipStrings_QtMultimedia[14490]
#define sipNameNr_playbackRate 14503
#define sipName_playbackRate &sipStrings_QtMultimedia[14503]
#define sipNameNr_setAudioRole 14516
#define sipName_setAudioRole &sipStrings_QtMultimedia[14516]
#define sipNameNr_setByteOrder 14529
#define sipName_setByteOrder &sipStrings_QtMultimedia[14529]
#define sipNameNr_setDriveMode 14542
#define sipName_setDriveMode &sipStrings_QtMultimedia[14542]
#define sipNameNr_setFieldType 14555
#define sipName_setFieldType &sipStrings_QtMultimedia[14555]
#define sipNameNr_setFlashMode 14568
#define sipName_setFlashMode &sipStrings_QtMultimedia[14568]
#define sipNameNr_setFocusMode 14581
#define sipName_setFocusMode &sipStrings_QtMultimedia[14581]
#define sipNameNr_setFrameRate 14594
#define sipName_setFrameRate &sipStrings_QtMultimedia[14594]
#define sipNameNr_setFrameSize 14607
#define sipName_setFrameSize &sipStrings_QtMultimedia[14607]
#define sipNameNr_setFrequency 14620
#define sipName_setFrequency &sipStrings_QtMultimedia[14620]
#define sipNameNr_setLoopCount 14633
#define sipName_setLoopCount &sipStrings_QtMultimedia[14633]
#define sipNameNr_setNextMedia 14646
#define sipName_setNextMedia &sipStrings_QtMultimedia[14646]
#define sipNameNr_setParameter 14659
#define sipName_setParameter &sipStrings_QtMultimedia[14659]
#define sipNameNr_setStartTime 14672
#define sipName_setStartTime &sipStrings_QtMultimedia[14672]
#define sipNameNr_shutterSpeed 14685
#define sipName_shutterSpeed &sipStrings_QtMultimedia[14685]
#define sipNameNr_sourceDevice 14698
#define sipName_sourceDevice &sipStrings_QtMultimedia[14698]
#define sipNameNr_stateChanged 14711
#define sipName_stateChanged &sipStrings_QtMultimedia[14711]
#define sipNameNr_stationFound 14724
#define sipName_stationFound &sipStrings_QtMultimedia[14724]
#define sipNameNr_videoBitRate 14737
#define sipName_videoBitRate &sipStrings_QtMultimedia[14737]
#define sipNameNr_ActiveState 14750
#define sipName_ActiveState &sipStrings_QtMultimedia[14750]
#define sipNameNr_AlbumArtist 14762
#define sipName_AlbumArtist &sipStrings_QtMultimedia[14762]
#define sipNameNr_AudioOutput 14023
#define sipName_AudioOutput &sipStrings_QtMultimedia[14023]
#define sipNameNr_AudioStream 14774
#define sipName_AudioStream &sipStrings_QtMultimedia[14774]
#define sipNameNr_BottomField 14786
#define sipName_BottomField &sipStrings_QtMultimedia[14786]
#define sipNameNr_BottomToTop 14798
#define sipName_BottomToTop &sipStrings_QtMultimedia[14798]
#define sipNameNr_CameraError 14810
#define sipName_CameraError &sipStrings_QtMultimedia[14810]
#define sipNameNr_CameraModel 14822
#define sipName_CameraModel &sipStrings_QtMultimedia[14822]
#define sipNameNr_CaptureMode 5493
#define sipName_CaptureMode &sipStrings_QtMultimedia[5493]
#define sipNameNr_ClassicRock 14834
#define sipName_ClassicRock &sipStrings_QtMultimedia[14834]
#define sipNameNr_ColorFilter 367
#define sipName_ColorFilter &sipStrings_QtMultimedia[367]
#define sipNameNr_Description 2755
#define sipName_Description &sipStrings_QtMultimedia[2755]
#define sipNameNr_Documentary 14846
#define sipName_Documentary &sipStrings_QtMultimedia[14846]
#define sipNameNr_FlashManual 14858
#define sipName_FlashManual &sipStrings_QtMultimedia[14858]
#define sipNameNr_FocalLength 14870
#define sipName_FocalLength &sipStrings_QtMultimedia[14870]
#define sipNameNr_ForceStereo 14882
#define sipName_ForceStereo &sipStrings_QtMultimedia[14882]
#define sipNameNr_FormatError 3928
#define sipName_FormatError &sipStrings_QtMultimedia[3928]
#define sipNameNr_Format_IMC1 14894
#define sipName_Format_IMC1 &sipStrings_QtMultimedia[14894]
#define sipNameNr_Format_IMC2 14906
#define sipName_Format_IMC2 &sipStrings_QtMultimedia[14906]
#define sipNameNr_Format_IMC3 14918
#define sipName_Format_IMC3 &sipStrings_QtMultimedia[14918]
#define sipNameNr_Format_IMC4 14930
#define sipName_Format_IMC4 &sipStrings_QtMultimedia[14930]
#define sipNameNr_Format_Jpeg 14942
#define sipName_Format_Jpeg &sipStrings_QtMultimedia[14942]
#define sipNameNr_Format_NV12 14954
#define sipName_Format_NV12 &sipStrings_QtMultimedia[14954]
#define sipNameNr_Format_NV21 14966
#define sipName_Format_NV21 &sipStrings_QtMultimedia[14966]
#define sipNameNr_Format_UYVY 14978
#define sipName_Format_UYVY &sipStrings_QtMultimedia[14978]
#define sipNameNr_Format_User 14990
#define sipName_Format_User &sipStrings_QtMultimedia[14990]
#define sipNameNr_Format_YUYV 15002
#define sipName_Format_YUYV &sipStrings_QtMultimedia[15002]
#define sipNameNr_Format_YV12 15014
#define sipName_Format_YV12 &sipStrings_QtMultimedia[15014]
#define sipNameNr_GPSAltitude 15026
#define sipName_GPSAltitude &sipStrings_QtMultimedia[15026]
#define sipNameNr_GPSLatitude 15038
#define sipName_GPSLatitude &sipStrings_QtMultimedia[15038]
#define sipNameNr_GPSMapDatum 15050
#define sipName_GPSMapDatum &sipStrings_QtMultimedia[15050]
#define sipNameNr_GPSTrackRef 15062
#define sipName_GPSTrackRef &sipStrings_QtMultimedia[15062]
#define sipNameNr_GainControl 15074
#define sipName_GainControl &sipStrings_QtMultimedia[15074]
#define sipNameNr_HighQuality 10855
#define sipName_HighQuality &sipStrings_QtMultimedia[10855]
#define sipNameNr_Information 7340
#define sipName_Information &sipStrings_QtMultimedia[7340]
#define sipNameNr_LastInChain 15086
#define sipName_LastInChain &sipStrings_QtMultimedia[15086]
#define sipNameNr_LightSource 15098
#define sipName_LightSource &sipStrings_QtMultimedia[15098]
#define sipNameNr_LoadedMedia 15110
#define sipName_LoadedMedia &sipStrings_QtMultimedia[15110]
#define sipNameNr_LoadedState 15122
#define sipName_LoadedState &sipStrings_QtMultimedia[15122]
#define sipNameNr_ManualFocus 15134
#define sipName_ManualFocus &sipStrings_QtMultimedia[15134]
#define sipNameNr_MediaStatus 2444
#define sipName_MediaStatus &sipStrings_QtMultimedia[2444]
#define sipNameNr_OldiesMusic 15146
#define sipName_OldiesMusic &sipStrings_QtMultimedia[15146]
#define sipNameNr_Orientation 8884
#define sipName_Orientation &sipStrings_QtMultimedia[8884]
#define sipNameNr_PausedState 15158
#define sipName_PausedState &sipStrings_QtMultimedia[15158]
#define sipNameNr_Personality 15170
#define sipName_Personality &sipStrings_QtMultimedia[15170]
#define sipNameNr_PixelFormat 2235
#define sipName_PixelFormat &sipStrings_QtMultimedia[2235]
#define sipNameNr_PosterImage 15182
#define sipName_PosterImage &sipStrings_QtMultimedia[15182]
#define sipNameNr_ProgramType 3267
#define sipName_ProgramType &sipStrings_QtMultimedia[3267]
#define sipNameNr_QAudioInput 15194
#define sipName_QAudioInput &sipStrings_QtMultimedia[15194]
#define sipNameNr_QAudioProbe 15206
#define sipName_QAudioProbe &sipStrings_QtMultimedia[15206]
#define sipNameNr_QCameraInfo 15218
#define sipName_QCameraInfo &sipStrings_QtMultimedia[15218]
#define sipNameNr_QMultimedia 15230
#define sipName_QMultimedia &sipStrings_QtMultimedia[15230]
#define sipNameNr_QRadioTuner 15242
#define sipName_QRadioTuner &sipStrings_QtMultimedia[15242]
#define sipNameNr_QVideoFrame 15254
#define sipName_QVideoFrame &sipStrings_QtMultimedia[15254]
#define sipNameNr_QVideoProbe 15266
#define sipName_QVideoProbe &sipStrings_QtMultimedia[15266]
#define sipNameNr_TopToBottom 15278
#define sipName_TopToBottom &sipStrings_QtMultimedia[15278]
#define sipNameNr_TrackNumber 15290
#define sipName_TrackNumber &sipStrings_QtMultimedia[15290]
#define sipNameNr_UnSignedInt 15302
#define sipName_UnSignedInt &sipStrings_QtMultimedia[15302]
#define sipNameNr_UnknownRole 15314
#define sipName_UnknownRole &sipStrings_QtMultimedia[15314]
#define sipNameNr_UserRequest 15326
#define sipName_UserRequest &sipStrings_QtMultimedia[15326]
#define sipNameNr_VideoStream 15338
#define sipName_VideoStream &sipStrings_QtMultimedia[15338]
#define sipNameNr_VolumeScale 3721
#define sipName_VolumeScale &sipStrings_QtMultimedia[3721]
#define sipNameNr_YCbCr_BT601 15350
#define sipName_YCbCr_BT601 &sipStrings_QtMultimedia[15350]
#define sipNameNr_YCbCr_BT709 15362
#define sipName_YCbCr_BT709 &sipStrings_QtMultimedia[15362]
#define sipNameNr_activeInput 15374
#define sipName_activeInput &sipStrings_QtMultimedia[15374]
#define sipNameNr_actualValue 15386
#define sipName_actualValue &sipStrings_QtMultimedia[15386]
#define sipNameNr_addInterval 15398
#define sipName_addInterval &sipStrings_QtMultimedia[15398]
#define sipNameNr_audioFormat 15410
#define sipName_audioFormat &sipStrings_QtMultimedia[15410]
#define sipNameNr_audioInputs 15422
#define sipName_audioInputs &sipStrings_QtMultimedia[15422]
#define sipNameNr_bandChanged 15434
#define sipName_bandChanged &sipStrings_QtMultimedia[15434]
#define sipNameNr_bufferReady 15446
#define sipName_bufferReady &sipStrings_QtMultimedia[15446]
#define sipNameNr_captureMode 15458
#define sipName_captureMode &sipStrings_QtMultimedia[15458]
#define sipNameNr_colorFilter 15470
#define sipName_colorFilter &sipStrings_QtMultimedia[15470]
#define sipNameNr_customEvent 15482
#define sipName_customEvent &sipStrings_QtMultimedia[15482]
#define sipNameNr_description 15494
#define sipName_description &sipStrings_QtMultimedia[15494]
#define sipNameNr_deviceCount 15506
#define sipName_deviceCount &sipStrings_QtMultimedia[15506]
#define sipNameNr_digitalZoom 15518
#define sipName_digitalZoom &sipStrings_QtMultimedia[15518]
#define sipNameNr_displayRect 15530
#define sipName_displayRect &sipStrings_QtMultimedia[15530]
#define sipNameNr_errorString 15542
#define sipName_errorString &sipStrings_QtMultimedia[15542]
#define sipNameNr_eventFilter 15554
#define sipName_eventFilter &sipStrings_QtMultimedia[15554]
#define sipNameNr_frameHeight 15566
#define sipName_frameHeight &sipStrings_QtMultimedia[15566]
#define sipNameNr_insertMedia 15578
#define sipName_insertMedia &sipStrings_QtMultimedia[15578]
#define sipNameNr_isAvailable 15590
#define sipName_isAvailable &sipStrings_QtMultimedia[15590]
#define sipNameNr_isSearching 15602
#define sipName_isSearching &sipStrings_QtMultimedia[15602]
#define sipNameNr_mappedBytes 15614
#define sipName_mappedBytes &sipStrings_QtMultimedia[15614]
#define sipNameNr_mediaObject 15626
#define sipName_mediaObject &sipStrings_QtMultimedia[15626]
#define sipNameNr_mediaStatus 15638
#define sipName_mediaStatus &sipStrings_QtMultimedia[15638]
#define sipNameNr_mediaStream 15650
#define sipName_mediaStream &sipStrings_QtMultimedia[15650]
#define sipNameNr_opticalZoom 15662
#define sipName_opticalZoom &sipStrings_QtMultimedia[15662]
#define sipNameNr_orientation 15674
#define sipName_orientation &sipStrings_QtMultimedia[15674]
#define sipNameNr_pixelFormat 15686
#define sipName_pixelFormat &sipStrings_QtMultimedia[15686]
#define sipNameNr_programType 15698
#define sipName_programType &sipStrings_QtMultimedia[15698]
#define sipNameNr_removeMedia 15710
#define sipName_removeMedia &sipStrings_QtMultimedia[15710]
#define sipNameNr_sampleCount 15722
#define sipName_sampleCount &sipStrings_QtMultimedia[15722]
#define sipNameNr_setCategory 15734
#define sipName_setCategory &sipStrings_QtMultimedia[15734]
#define sipNameNr_setContrast 15746
#define sipName_setContrast &sipStrings_QtMultimedia[15746]
#define sipNameNr_setDataSize 15758
#define sipName_setDataSize &sipStrings_QtMultimedia[15758]
#define sipNameNr_setLanguage 15770
#define sipName_setLanguage &sipStrings_QtMultimedia[15770]
#define sipNameNr_setMetaData 15782
#define sipName_setMetaData &sipStrings_QtMultimedia[15782]
#define sipNameNr_setMirrored 15794
#define sipName_setMirrored &sipStrings_QtMultimedia[15794]
#define sipNameNr_setPlaylist 15806
#define sipName_setPlaylist &sipStrings_QtMultimedia[15806]
#define sipNameNr_setPosition 15818
#define sipName_setPosition &sipStrings_QtMultimedia[15818]
#define sipNameNr_setProperty 15830
#define sipName_setProperty &sipStrings_QtMultimedia[15830]
#define sipNameNr_setViewport 15842
#define sipName_setViewport &sipStrings_QtMultimedia[15842]
#define sipNameNr_stationName 15854
#define sipName_stationName &sipStrings_QtMultimedia[15854]
#define sipNameNr_streamCount 15866
#define sipName_streamCount &sipStrings_QtMultimedia[15866]
#define sipNameNr_AlbumTitle 15878
#define sipName_AlbumTitle &sipStrings_QtMultimedia[15878]
#define sipNameNr_AudioCodec 13409
#define sipName_AudioCodec &sipStrings_QtMultimedia[13409]
#define sipNameNr_AudioInput 8939
#define sipName_AudioInput &sipStrings_QtMultimedia[8939]
#define sipNameNr_Brightness 13437
#define sipName_Brightness &sipStrings_QtMultimedia[13437]
#define sipNameNr_CustomRole 15889
#define sipName_CustomRole &sipStrings_QtMultimedia[15889]
#define sipNameNr_DataStream 15900
#define sipName_DataStream &sipStrings_QtMultimedia[15900]
#define sipNameNr_EndOfMedia 15911
#define sipName_EndOfMedia &sipStrings_QtMultimedia[15911]
#define sipNameNr_FatalError 15922
#define sipName_FatalError &sipStrings_QtMultimedia[15922]
#define sipNameNr_FlashModes 1794
#define sipName_FlashModes &sipStrings_QtMultimedia[1794]
#define sipNameNr_FlashPower 15933
#define sipName_FlashPower &sipStrings_QtMultimedia[15933]
#define sipNameNr_FlashTorch 15944
#define sipName_FlashTorch &sipStrings_QtMultimedia[15944]
#define sipNameNr_FocusModes 2856
#define sipName_FocusModes &sipStrings_QtMultimedia[2856]
#define sipNameNr_Format_Y16 15955
#define sipName_Format_Y16 &sipStrings_QtMultimedia[15955]
#define sipNameNr_HandleType 607
#define sipName_HandleType &sipStrings_QtMultimedia[607]
#define sipNameNr_ImageError 15966
#define sipName_ImageError &sipStrings_QtMultimedia[15966]
#define sipNameNr_ImageSaved 15977
#define sipName_ImageSaved &sipStrings_QtMultimedia[15977]
#define sipNameNr_LockFailed 15988
#define sipName_LockFailed &sipStrings_QtMultimedia[15988]
#define sipNameNr_LockStatus 6407
#define sipName_LockStatus &sipStrings_QtMultimedia[6407]
#define sipNameNr_LowLatency 15999
#define sipName_LowLatency &sipStrings_QtMultimedia[15999]
#define sipNameNr_LowQuality 11957
#define sipName_LowQuality &sipStrings_QtMultimedia[11957]
#define sipNameNr_MacroFocus 16010
#define sipName_MacroFocus &sipStrings_QtMultimedia[16010]
#define sipNameNr_OtherMusic 16021
#define sipName_OtherMusic &sipStrings_QtMultimedia[16021]
#define sipNameNr_QRadioData 16032
#define sipName_QRadioData &sipStrings_QtMultimedia[16032]
#define sipNameNr_Resolution 7047
#define sipName_Resolution &sipStrings_QtMultimedia[7047]
#define sipNameNr_SampleRate 13493
#define sipName_SampleRate &sipStrings_QtMultimedia[13493]
#define sipNameNr_SampleType 2831
#define sipName_SampleType &sipStrings_QtMultimedia[2831]
#define sipNameNr_Saturation 13535
#define sipName_Saturation &sipStrings_QtMultimedia[13535]
#define sipNameNr_SearchFast 16043
#define sipName_SearchFast &sipStrings_QtMultimedia[16043]
#define sipNameNr_SearchMode 3292
#define sipName_SearchMode &sipStrings_QtMultimedia[3292]
#define sipNameNr_Sequential 16054
#define sipName_Sequential &sipStrings_QtMultimedia[16054]
#define sipNameNr_Sharpening 16065
#define sipName_Sharpening &sipStrings_QtMultimedia[16065]
#define sipNameNr_StereoMode 3316
#define sipName_StereoMode &sipStrings_QtMultimedia[3316]
#define sipNameNr_StreamType 739
#define sipName_StreamType &sipStrings_QtMultimedia[739]
#define sipNameNr_TorchPower 16076
#define sipName_TorchPower &sipStrings_QtMultimedia[16076]
#define sipNameNr_TrackCount 16087
#define sipName_TrackCount &sipStrings_QtMultimedia[16087]
#define sipNameNr_UserHandle 16098
#define sipName_UserHandle &sipStrings_QtMultimedia[16098]
#define sipNameNr_UserRating 16109
#define sipName_UserRating &sipStrings_QtMultimedia[16109]
#define sipNameNr_VideoCodec 13563
#define sipName_VideoCodec &sipStrings_QtMultimedia[13563]
#define sipNameNr_Viewfinder 8363
#define sipName_Viewfinder &sipStrings_QtMultimedia[8363]
#define sipNameNr_YCbCr_JPEG 16120
#define sipName_YCbCr_JPEG &sipStrings_QtMultimedia[16120]
#define sipNameNr___invert__ 16131
#define sipName___invert__ &sipStrings_QtMultimedia[16131]
#define sipNameNr_audioCodec 16142
#define sipName_audioCodec &sipStrings_QtMultimedia[16142]
#define sipNameNr_audioInput 16153
#define sipName_audioInput &sipStrings_QtMultimedia[16153]
#define sipNameNr_brightness 16164
#define sipName_brightness &sipStrings_QtMultimedia[16164]
#define sipNameNr_bufferSize 16175
#define sipName_bufferSize &sipStrings_QtMultimedia[16175]
#define sipNameNr_bytesReady 16186
#define sipName_bytesReady &sipStrings_QtMultimedia[16186]
#define sipNameNr_childEvent 16197
#define sipName_childEvent &sipStrings_QtMultimedia[16197]
#define sipNameNr_contentUrl 16208
#define sipName_contentUrl &sipStrings_QtMultimedia[16208]
#define sipNameNr_continuous 16219
#define sipName_continuous &sipStrings_QtMultimedia[16219]
#define sipNameNr_deviceName 16230
#define sipName_deviceName &sipStrings_QtMultimedia[16230]
#define sipNameNr_flashReady 16241
#define sipName_flashReady &sipStrings_QtMultimedia[16241]
#define sipNameNr_focusZones 16252
#define sipName_focusZones &sipStrings_QtMultimedia[16252]
#define sipNameNr_frameCount 16263
#define sipName_frameCount &sipStrings_QtMultimedia[16263]
#define sipNameNr_frameWidth 16274
#define sipName_frameWidth &sipStrings_QtMultimedia[16274]
#define sipNameNr_handleType 16285
#define sipName_handleType &sipStrings_QtMultimedia[16285]
#define sipNameNr_hasSupport 16296
#define sipName_hasSupport &sipStrings_QtMultimedia[16296]
#define sipNameNr_hueChanged 16307
#define sipName_hueChanged &sipStrings_QtMultimedia[16307]
#define sipNameNr_imageSaved 16318
#define sipName_imageSaved &sipStrings_QtMultimedia[16318]
#define sipNameNr_isFinished 16329
#define sipName_isFinished &sipStrings_QtMultimedia[16329]
#define sipNameNr_isMirrored 16340
#define sipName_isMirrored &sipStrings_QtMultimedia[16340]
#define sipNameNr_isReadOnly 16351
#define sipName_isReadOnly &sipStrings_QtMultimedia[16351]
#define sipNameNr_isReadable 16362
#define sipName_isReadable &sipStrings_QtMultimedia[16362]
#define sipNameNr_isSeekable 16373
#define sipName_isSeekable &sipStrings_QtMultimedia[16373]
#define sipNameNr_isWritable 16384
#define sipName_isWritable &sipStrings_QtMultimedia[16384]
#define sipNameNr_latestTime 16395
#define sipName_latestTime &sipStrings_QtMultimedia[16395]
#define sipNameNr_loadFailed 16406
#define sipName_loadFailed &sipStrings_QtMultimedia[16406]
#define sipNameNr_lockFailed 16417
#define sipName_lockFailed &sipStrings_QtMultimedia[16417]
#define sipNameNr_lockStatus 16428
#define sipName_lockStatus &sipStrings_QtMultimedia[16428]
#define sipNameNr_mediaCount 16439
#define sipName_mediaCount &sipStrings_QtMultimedia[16439]
#define sipNameNr_nativeSize 16450
#define sipName_nativeSize &sipStrings_QtMultimedia[16450]
#define sipNameNr_normalized 16461
#define sipName_normalized &sipStrings_QtMultimedia[16461]
#define sipNameNr_periodSize 16472
#define sipName_periodSize &sipStrings_QtMultimedia[16472]
#define sipNameNr_planeCount 16483
#define sipName_planeCount &sipStrings_QtMultimedia[16483]
#define sipNameNr_resolution 16494
#define sipName_resolution &sipStrings_QtMultimedia[16494]
#define sipNameNr_sampleRate 16505
#define sipName_sampleRate &sipStrings_QtMultimedia[16505]
#define sipNameNr_sampleSize 16516
#define sipName_sampleSize &sipStrings_QtMultimedia[16516]
#define sipNameNr_sampleType 16527
#define sipName_sampleType &sipStrings_QtMultimedia[16527]
#define sipNameNr_saturation 16538
#define sipName_saturation &sipStrings_QtMultimedia[16538]
#define sipNameNr_searchMode 16549
#define sipName_searchMode &sipStrings_QtMultimedia[16549]
#define sipNameNr_setBitRate 16560
#define sipName_setBitRate &sipStrings_QtMultimedia[16560]
#define sipNameNr_setEndTime 16571
#define sipName_setEndTime &sipStrings_QtMultimedia[16571]
#define sipNameNr_setQuality 16582
#define sipName_setQuality &sipStrings_QtMultimedia[16582]
#define sipNameNr_setSurface 16593
#define sipName_setSurface &sipStrings_QtMultimedia[16593]
#define sipNameNr_stereoMode 16604
#define sipName_stereoMode &sipStrings_QtMultimedia[16604]
#define sipNameNr_streamType 16615
#define sipName_streamType &sipStrings_QtMultimedia[16615]
#define sipNameNr_timerEvent 16626
#define sipName_timerEvent &sipStrings_QtMultimedia[16626]
#define sipNameNr_translated 16637
#define sipName_translated &sipStrings_QtMultimedia[16637]
#define sipNameNr_videoCodec 16648
#define sipName_videoCodec &sipStrings_QtMultimedia[16648]
#define sipNameNr_AdultHits 16659
#define sipName_AdultHits &sipStrings_QtMultimedia[16659]
#define sipNameNr_AlarmRole 16669
#define sipName_AlarmRole &sipStrings_QtMultimedia[16669]
#define sipNameNr_AlarmTest 16679
#define sipName_AlarmTest &sipStrings_QtMultimedia[16679]
#define sipNameNr_AutoFocus 16689
#define sipName_AutoFocus &sipStrings_QtMultimedia[16689]
#define sipNameNr_Available 4045
#define sipName_Available &sipStrings_QtMultimedia[4045]
#define sipNameNr_BigEndian 16699
#define sipName_BigEndian &sipStrings_QtMultimedia[16699]
#define sipNameNr_Classical 9781
#define sipName_Classical &sipStrings_QtMultimedia[9781]
#define sipNameNr_Conductor 16709
#define sipName_Conductor &sipStrings_QtMultimedia[16709]
#define sipNameNr_Copyright 16719
#define sipName_Copyright &sipStrings_QtMultimedia[16719]
#define sipNameNr_Denoising 16729
#define sipName_Denoising &sipStrings_QtMultimedia[16729]
#define sipNameNr_Direction 1089
#define sipName_Direction &sipStrings_QtMultimedia[1089]
#define sipNameNr_DriveMode 996
#define sipName_DriveMode &sipStrings_QtMultimedia[996]
#define sipNameNr_Education 16739
#define sipName_Education &sipStrings_QtMultimedia[16739]
#define sipNameNr_EventType 507
#define sipName_EventType &sipStrings_QtMultimedia[507]
#define sipNameNr_FieldType 3907
#define sipName_FieldType &sipStrings_QtMultimedia[3907]
#define sipNameNr_FlashAuto 16749
#define sipName_FlashAuto &sipStrings_QtMultimedia[16749]
#define sipNameNr_FlashFill 16759
#define sipName_FlashFill &sipStrings_QtMultimedia[16759]
#define sipNameNr_FlashMode 2129
#define sipName_FlashMode &sipStrings_QtMultimedia[2129]
#define sipNameNr_FocusMode 3101
#define sipName_FocusMode &sipStrings_QtMultimedia[3101]
#define sipNameNr_FolkMusic 16769
#define sipName_FolkMusic &sipStrings_QtMultimedia[16769]
#define sipNameNr_ForceMono 16779
#define sipName_ForceMono &sipStrings_QtMultimedia[16779]
#define sipNameNr_Format_Y8 16789
#define sipName_Format_Y8 &sipStrings_QtMultimedia[16789]
#define sipNameNr_FrontFace 16799
#define sipName_FrontFace &sipStrings_QtMultimedia[16799]
#define sipNameNr_GPSStatus 16809
#define sipName_GPSStatus &sipStrings_QtMultimedia[16809]
#define sipNameNr_IdleState 16819
#define sipName_IdleState &sipStrings_QtMultimedia[16819]
#define sipNameNr_JazzMusic 16829
#define sipName_JazzMusic &sipStrings_QtMultimedia[16829]
#define sipNameNr_LockFocus 16839
#define sipName_LockFocus &sipStrings_QtMultimedia[16839]
#define sipNameNr_LockTypes 7399
#define sipName_LockTypes &sipStrings_QtMultimedia[7399]
#define sipNameNr_MediaType 16849
#define sipName_MediaType &sipStrings_QtMultimedia[16849]
#define sipNameNr_MusicRole 16859
#define sipName_MusicRole &sipStrings_QtMultimedia[16859]
#define sipNameNr_Nostalgia 16869
#define sipName_Nostalgia &sipStrings_QtMultimedia[16869]
#define sipNameNr_NotMapped 16879
#define sipName_NotMapped &sipStrings_QtMultimedia[16879]
#define sipNameNr_OpenError 16889
#define sipName_OpenError &sipStrings_QtMultimedia[16889]
#define sipNameNr_PeakValue 16899
#define sipName_PeakValue &sipStrings_QtMultimedia[16899]
#define sipNameNr_PosterUrl 16909
#define sipName_PosterUrl &sipStrings_QtMultimedia[16909]
#define sipNameNr_Publisher 16919
#define sipName_Publisher &sipStrings_QtMultimedia[16919]
#define sipNameNr_ReadWrite 16929
#define sipName_ReadWrite &sipStrings_QtMultimedia[16929]
#define sipNameNr_RockMusic 16939
#define sipName_RockMusic &sipStrings_QtMultimedia[16939]
#define sipNameNr_Searching 15604
#define sipName_Searching &sipStrings_QtMultimedia[15604]
#define sipNameNr_Sharpness 16949
#define sipName_Sharpness &sipStrings_QtMultimedia[16949]
#define sipNameNr_SignedInt 15304
#define sipName_SignedInt &sipStrings_QtMultimedia[15304]
#define sipNameNr_Undefined 10873
#define sipName_Undefined &sipStrings_QtMultimedia[10873]
#define sipNameNr_VideoRole 16959
#define sipName_VideoRole &sipStrings_QtMultimedia[16959]
#define sipNameNr_WriteOnly 16969
#define sipName_WriteOnly &sipStrings_QtMultimedia[16969]
#define sipNameNr___index__ 16979
#define sipName___index__ &sipStrings_QtMultimedia[16979]
#define sipNameNr_audioRole 16989
#define sipName_audioRole &sipStrings_QtMultimedia[16989]
#define sipNameNr_byteCount 16999
#define sipName_byteCount &sipStrings_QtMultimedia[16999]
#define sipNameNr_byteOrder 17009
#define sipName_byteOrder &sipStrings_QtMultimedia[17009]
#define sipNameNr_bytesFree 17019
#define sipName_bytesFree &sipStrings_QtMultimedia[17019]
#define sipNameNr_constData 17029
#define sipName_constData &sipStrings_QtMultimedia[17029]
#define sipNameNr_container 17039
#define sipName_container &sipStrings_QtMultimedia[17039]
#define sipNameNr_driveMode 17049
#define sipName_driveMode &sipStrings_QtMultimedia[17049]
#define sipNameNr_fieldType 17059
#define sipName_fieldType &sipStrings_QtMultimedia[17059]
#define sipNameNr_flashMode 17069
#define sipName_flashMode &sipStrings_QtMultimedia[17069]
#define sipNameNr_focusMode 17079
#define sipName_focusMode &sipStrings_QtMultimedia[17079]
#define sipNameNr_frameRate 17089
#define sipName_frameRate &sipStrings_QtMultimedia[17089]
#define sipNameNr_frameSize 17099
#define sipName_frameSize &sipStrings_QtMultimedia[17099]
#define sipNameNr_frequency 17109
#define sipName_frequency &sipStrings_QtMultimedia[17109]
#define sipNameNr_intervals 17119
#define sipName_intervals &sipStrings_QtMultimedia[17119]
#define sipNameNr_isPlaying 17129
#define sipName_isPlaying &sipStrings_QtMultimedia[17129]
#define sipNameNr_loopCount 17139
#define sipName_loopCount &sipStrings_QtMultimedia[17139]
#define sipNameNr_moveMedia 15712
#define sipName_moveMedia &sipStrings_QtMultimedia[15712]
#define sipNameNr_nextIndex 17149
#define sipName_nextIndex &sipStrings_QtMultimedia[17149]
#define sipNameNr_nextMedia 17159
#define sipName_nextMedia &sipStrings_QtMultimedia[17159]
#define sipNameNr_parameter 17169
#define sipName_parameter &sipStrings_QtMultimedia[17169]
#define sipNameNr_radioData 17179
#define sipName_radioData &sipStrings_QtMultimedia[17179]
#define sipNameNr_radioText 17189
#define sipName_radioText &sipStrings_QtMultimedia[17189]
#define sipNameNr_resources 17199
#define sipName_resources &sipStrings_QtMultimedia[17199]
#define sipNameNr_setActive 17209
#define sipName_setActive &sipStrings_QtMultimedia[17209]
#define sipNameNr_setSource 17219
#define sipName_setSource &sipStrings_QtMultimedia[17219]
#define sipNameNr_setVolume 17229
#define sipName_setVolume &sipStrings_QtMultimedia[17229]
#define sipNameNr_startTime 17239
#define sipName_startTime &sipStrings_QtMultimedia[17239]
#define sipNameNr_stationId 17249
#define sipName_stationId &sipStrings_QtMultimedia[17249]
#define sipNameNr_Aperture 4342
#define sipName_Aperture &sipStrings_QtMultimedia[4342]
#define sipNameNr_BackFace 17259
#define sipName_BackFace &sipStrings_QtMultimedia[17259]
#define sipNameNr_Category 15737
#define sipName_Category &sipStrings_QtMultimedia[15737]
#define sipNameNr_Composer 17268
#define sipName_Composer &sipStrings_QtMultimedia[17268]
#define sipNameNr_Contrast 15749
#define sipName_Contrast &sipStrings_QtMultimedia[15749]
#define sipNameNr_Director 17277
#define sipName_Director &sipStrings_QtMultimedia[17277]
#define sipNameNr_Duration 9013
#define sipName_Duration &sipStrings_QtMultimedia[9013]
#define sipNameNr_FlashOff 17286
#define sipName_FlashOff &sipStrings_QtMultimedia[17286]
#define sipNameNr_GPSSpeed 17295
#define sipName_GPSSpeed &sipStrings_QtMultimedia[17295]
#define sipNameNr_GPSTrack 17304
#define sipName_GPSTrack &sipStrings_QtMultimedia[17304]
#define sipNameNr_GameRole 17313
#define sipName_GameRole &sipStrings_QtMultimedia[17313]
#define sipNameNr_Infinite 17322
#define sipName_Infinite &sipStrings_QtMultimedia[17322]
#define sipNameNr_Keywords 17331
#define sipName_Keywords &sipStrings_QtMultimedia[17331]
#define sipNameNr_Language 15773
#define sipName_Language &sipStrings_QtMultimedia[15773]
#define sipNameNr_LockLost 17340
#define sipName_LockLost &sipStrings_QtMultimedia[17340]
#define sipNameNr_LockType 8635
#define sipName_LockType &sipStrings_QtMultimedia[8635]
#define sipNameNr_NoHandle 17349
#define sipName_NoHandle &sipStrings_QtMultimedia[17349]
#define sipNameNr_PopMusic 17358
#define sipName_PopMusic &sipStrings_QtMultimedia[17358]
#define sipNameNr_Position 6689
#define sipName_Position &sipStrings_QtMultimedia[6689]
#define sipNameNr_ReadOnly 16353
#define sipName_ReadOnly &sipStrings_QtMultimedia[16353]
#define sipNameNr_Religion 17367
#define sipName_Religion &sipStrings_QtMultimedia[17367]
#define sipNameNr_RunFlags 1059
#define sipName_RunFlags &sipStrings_QtMultimedia[1059]
#define sipNameNr_Selected 17376
#define sipName_Selected &sipStrings_QtMultimedia[17376]
#define sipNameNr_SoftRock 17385
#define sipName_SoftRock &sipStrings_QtMultimedia[17385]
#define sipNameNr_SubTitle 17394
#define sipName_SubTitle &sipStrings_QtMultimedia[17394]
#define sipNameNr_TopField 17403
#define sipName_TopField &sipStrings_QtMultimedia[17403]
#define sipNameNr_Unlocked 17412
#define sipName_Unlocked &sipStrings_QtMultimedia[17412]
#define sipNameNr___bool__ 17421
#define sipName___bool__ &sipStrings_QtMultimedia[17421]
#define sipNameNr___hash__ 17430
#define sipName___hash__ &sipStrings_QtMultimedia[17430]
#define sipNameNr___iadd__ 17439
#define sipName___iadd__ &sipStrings_QtMultimedia[17439]
#define sipNameNr___iand__ 17448
#define sipName___iand__ &sipStrings_QtMultimedia[17448]
#define sipNameNr___isub__ 17457
#define sipName___isub__ &sipStrings_QtMultimedia[17457]
#define sipNameNr___ixor__ 17466
#define sipName___ixor__ &sipStrings_QtMultimedia[17466]
#define sipNameNr_addMedia 17475
#define sipName_addMedia &sipStrings_QtMultimedia[17475]
#define sipNameNr_aperture 17484
#define sipName_aperture &sipStrings_QtMultimedia[17484]
#define sipNameNr_category 17493
#define sipName_category &sipStrings_QtMultimedia[17493]
#define sipNameNr_contains 17502
#define sipName_contains &sipStrings_QtMultimedia[17502]
#define sipNameNr_contrast 17511
#define sipName_contrast &sipStrings_QtMultimedia[17511]
#define sipNameNr_dataSize 17520
#define sipName_dataSize &sipStrings_QtMultimedia[17520]
#define sipNameNr_duration 17529
#define sipName_duration &sipStrings_QtMultimedia[17529]
#define sipNameNr_exposure 17538
#define sipName_exposure &sipStrings_QtMultimedia[17538]
#define sipNameNr_fileName 17547
#define sipName_fileName &sipStrings_QtMultimedia[17547]
#define sipNameNr_finished 17556
#define sipName_finished &sipStrings_QtMultimedia[17556]
#define sipNameNr_isActive 17565
#define sipName_isActive &sipStrings_QtMultimedia[17565]
#define sipNameNr_isLoaded 17574
#define sipName_isLoaded &sipStrings_QtMultimedia[17574]
#define sipNameNr_isMapped 17583
#define sipName_isMapped &sipStrings_QtMultimedia[17583]
#define sipNameNr_isNormal 17592
#define sipName_isNormal &sipStrings_QtMultimedia[17592]
#define sipNameNr_isStereo 17601
#define sipName_isStereo &sipStrings_QtMultimedia[17601]
#define sipNameNr_language 17610
#define sipName_language &sipStrings_QtMultimedia[17610]
#define sipNameNr_metaData 17619
#define sipName_metaData &sipStrings_QtMultimedia[17619]
#define sipNameNr_mimeType 17628
#define sipName_mimeType &sipStrings_QtMultimedia[17628]
#define sipNameNr_playlist 17637
#define sipName_playlist &sipStrings_QtMultimedia[17637]
#define sipNameNr_position 17646
#define sipName_position &sipStrings_QtMultimedia[17646]
#define sipNameNr_previous 17655
#define sipName_previous &sipStrings_QtMultimedia[17655]
#define sipNameNr_property 17664
#define sipName_property &sipStrings_QtMultimedia[17664]
#define sipNameNr_setCodec 17673
#define sipName_setCodec &sipStrings_QtMultimedia[17673]
#define sipNameNr_setError 17682
#define sipName_setError &sipStrings_QtMultimedia[17682]
#define sipNameNr_setLoops 17691
#define sipName_setLoops &sipStrings_QtMultimedia[17691]
#define sipNameNr_setMedia 17700
#define sipName_setMedia &sipStrings_QtMultimedia[17700]
#define sipNameNr_setMuted 17709
#define sipName_setMuted &sipStrings_QtMultimedia[17709]
#define sipNameNr_setState 17718
#define sipName_setState &sipStrings_QtMultimedia[17718]
#define sipNameNr_setValue 17727
#define sipName_setValue &sipStrings_QtMultimedia[17727]
#define sipNameNr_setWinId 17736
#define sipName_setWinId &sipStrings_QtMultimedia[17736]
#define sipNameNr_settings 17745
#define sipName_settings &sipStrings_QtMultimedia[17745]
#define sipNameNr_sizeHint 17754
#define sipName_sizeHint &sipStrings_QtMultimedia[17754]
#define sipNameNr_viewport 17763
#define sipName_viewport &sipStrings_QtMultimedia[17763]
#define sipNameNr_College 17772
#define sipName_College &sipStrings_QtMultimedia[17772]
#define sipNameNr_Comment 17780
#define sipName_Comment &sipStrings_QtMultimedia[17780]
#define sipNameNr_Culture 17788
#define sipName_Culture &sipStrings_QtMultimedia[17788]
#define sipNameNr_FNumber 17796
#define sipName_FNumber &sipStrings_QtMultimedia[17796]
#define sipNameNr_Finance 17804
#define sipName_Finance &sipStrings_QtMultimedia[17804]
#define sipNameNr_FlashOn 17812
#define sipName_FlashOn &sipStrings_QtMultimedia[17812]
#define sipNameNr_Focused 17820
#define sipName_Focused &sipStrings_QtMultimedia[17820]
#define sipNameNr_IOError 17828
#define sipName_IOError &sipStrings_QtMultimedia[17828]
#define sipNameNr_Invalid 11585
#define sipName_Invalid &sipStrings_QtMultimedia[11585]
#define sipNameNr_Leisure 17836
#define sipName_Leisure &sipStrings_QtMultimedia[17836]
#define sipNameNr_Loading 17844
#define sipName_Loading &sipStrings_QtMultimedia[17844]
#define sipNameNr_MapMode 1274
#define sipName_MapMode &sipStrings_QtMultimedia[1274]
#define sipNameNr_NoError 17852
#define sipName_NoError &sipStrings_QtMultimedia[17852]
#define sipNameNr_NoMedia 17860
#define sipName_NoMedia &sipStrings_QtMultimedia[17860]
#define sipNameNr_PhoneIn 17868
#define sipName_PhoneIn &sipStrings_QtMultimedia[17868]
#define sipNameNr_QCamera 17876
#define sipName_QCamera &sipStrings_QtMultimedia[17876]
#define sipNameNr_RunFlag 1394
#define sipName_RunFlag &sipStrings_QtMultimedia[1394]
#define sipNameNr_Science 17884
#define sipName_Science &sipStrings_QtMultimedia[17884]
#define sipNameNr_Subject 17892
#define sipName_Subject &sipStrings_QtMultimedia[17892]
#define sipNameNr_Unknown 17900
#define sipName_Unknown &sipStrings_QtMultimedia[17900]
#define sipNameNr_Weather 17908
#define sipName_Weather &sipStrings_QtMultimedia[17908]
#define sipNameNr___add__ 17916
#define sipName___add__ &sipStrings_QtMultimedia[17916]
#define sipNameNr___and__ 17924
#define sipName___and__ &sipStrings_QtMultimedia[17924]
#define sipNameNr___int__ 17932
#define sipName___int__ &sipStrings_QtMultimedia[17932]
#define sipNameNr___ior__ 17940
#define sipName___ior__ &sipStrings_QtMultimedia[17940]
#define sipNameNr___sub__ 17948
#define sipName___sub__ &sipStrings_QtMultimedia[17948]
#define sipNameNr___xor__ 17956
#define sipName___xor__ &sipStrings_QtMultimedia[17956]
#define sipNameNr_bitRate 17964
#define sipName_bitRate &sipStrings_QtMultimedia[17964]
#define sipNameNr_capture 17972
#define sipName_capture &sipStrings_QtMultimedia[17972]
#define sipNameNr_endTime 17980
#define sipName_endTime &sipStrings_QtMultimedia[17980]
#define sipNameNr_isEmpty 17988
#define sipName_isEmpty &sipStrings_QtMultimedia[17988]
#define sipNameNr_isMuted 17996
#define sipName_isMuted &sipStrings_QtMultimedia[17996]
#define sipNameNr_isValid 18004
#define sipName_isValid &sipStrings_QtMultimedia[18004]
#define sipNameNr_mapMode 18012
#define sipName_mapMode &sipStrings_QtMultimedia[18012]
#define sipNameNr_present 18020
#define sipName_present &sipStrings_QtMultimedia[18020]
#define sipNameNr_quality 18028
#define sipName_quality &sipStrings_QtMultimedia[18028]
#define sipNameNr_release 18036
#define sipName_release &sipStrings_QtMultimedia[18036]
#define sipNameNr_repaint 18044
#define sipName_repaint &sipStrings_QtMultimedia[18044]
#define sipNameNr_request 18052
#define sipName_request &sipStrings_QtMultimedia[18052]
#define sipNameNr_service 18060
#define sipName_service &sipStrings_QtMultimedia[18060]
#define sipNameNr_setBand 18068
#define sipName_setBand &sipStrings_QtMultimedia[18068]
#define sipNameNr_shuffle 18076
#define sipName_shuffle &sipStrings_QtMultimedia[18076]
#define sipNameNr_surface 18084
#define sipName_surface &sipStrings_QtMultimedia[18084]
#define sipNameNr_suspend 18092
#define sipName_suspend &sipStrings_QtMultimedia[18092]
#define sipNameNr_Author 18100
#define sipName_Author &sipStrings_QtMultimedia[18100]
#define sipNameNr_Endian 5477
#define sipName_Endian &sipStrings_QtMultimedia[5477]
#define sipNameNr_GPSDOP 18107
#define sipName_GPSDOP &sipStrings_QtMultimedia[18107]
#define sipNameNr_Locked 4850
#define sipName_Locked &sipStrings_QtMultimedia[4850]
#define sipNameNr_Lyrics 18114
#define sipName_Lyrics &sipStrings_QtMultimedia[18114]
#define sipNameNr_NoLock 18121
#define sipName_NoLock &sipStrings_QtMultimedia[18121]
#define sipNameNr_Public 18128
#define sipName_Public &sipStrings_QtMultimedia[18128]
#define sipNameNr_QAudio 18135
#define sipName_QAudio &sipStrings_QtMultimedia[18135]
#define sipNameNr_QSound 18142
#define sipName_QSound &sipStrings_QtMultimedia[18142]
#define sipNameNr_Random 18149
#define sipName_Random &sipStrings_QtMultimedia[18149]
#define sipNameNr_Status 544
#define sipName_Status &sipStrings_QtMultimedia[544]
#define sipNameNr_Travel 18156
#define sipName_Travel &sipStrings_QtMultimedia[18156]
#define sipNameNr_Unused 18163
#define sipName_Unused &sipStrings_QtMultimedia[18163]
#define sipNameNr_Varied 18170
#define sipName_Varied &sipStrings_QtMultimedia[18170]
#define sipNameNr_Writer 18177
#define sipName_Writer &sipStrings_QtMultimedia[18177]
#define sipNameNr___eq__ 18184
#define sipName___eq__ &sipStrings_QtMultimedia[18184]
#define sipNameNr___ne__ 18191
#define sipName___ne__ &sipStrings_QtMultimedia[18191]
#define sipNameNr___or__ 18198
#define sipName___or__ &sipStrings_QtMultimedia[18198]
#define sipNameNr_buffer 18205
#define sipName_buffer &sipStrings_QtMultimedia[18205]
#define sipNameNr_codecs 18212
#define sipName_codecs &sipStrings_QtMultimedia[18212]
#define sipNameNr_format 18219
#define sipName_format &sipStrings_QtMultimedia[18219]
#define sipNameNr_handle 18226
#define sipName_handle &sipStrings_QtMultimedia[18226]
#define sipNameNr_height 18233
#define sipName_height &sipStrings_QtMultimedia[18233]
#define sipNameNr_isNull 18240
#define sipName_isNull &sipStrings_QtMultimedia[18240]
#define sipNameNr_loaded 18247
#define sipName_loaded &sipStrings_QtMultimedia[18247]
#define sipNameNr_locked 17414
#define sipName_locked &sipStrings_QtMultimedia[17414]
#define sipNameNr_notify 18254
#define sipName_notify &sipStrings_QtMultimedia[18254]
#define sipNameNr_parent 18261
#define sipName_parent &sipStrings_QtMultimedia[18261]
#define sipNameNr_record 18268
#define sipName_record &sipStrings_QtMultimedia[18268]
#define sipNameNr_resume 18275
#define sipName_resume &sipStrings_QtMultimedia[18275]
#define sipNameNr_setHue 18282
#define sipName_setHue &sipStrings_QtMultimedia[18282]
#define sipNameNr_source 8925
#define sipName_source &sipStrings_QtMultimedia[8925]
#define sipNameNr_status 18289
#define sipName_status &sipStrings_QtMultimedia[18289]
#define sipNameNr_stream 18296
#define sipName_stream &sipStrings_QtMultimedia[18296]
#define sipNameNr_unbind 18303
#define sipName_unbind &sipStrings_QtMultimedia[18303]
#define sipNameNr_unload 18310
#define sipName_unload &sipStrings_QtMultimedia[18310]
#define sipNameNr_unlock 18317
#define sipName_unlock &sipStrings_QtMultimedia[18317]
#define sipNameNr_volume 18324
#define sipName_volume &sipStrings_QtMultimedia[18324]
#define sipNameNr_zoomTo 18331
#define sipName_zoomTo &sipStrings_QtMultimedia[18331]
#define sipNameNr_Alarm 18338
#define sipName_Alarm &sipStrings_QtMultimedia[18338]
#define sipNameNr_Drama 18344
#define sipName_Drama &sipStrings_QtMultimedia[18344]
#define sipNameNr_Error 1484
#define sipName_Error &sipStrings_QtMultimedia[1484]
#define sipNameNr_Event 15488
#define sipName_Event &sipStrings_QtMultimedia[15488]
#define sipNameNr_Flags 1062
#define sipName_Flags &sipStrings_QtMultimedia[1062]
#define sipNameNr_Flash 8782
#define sipName_Flash &sipStrings_QtMultimedia[8782]
#define sipNameNr_Float 18350
#define sipName_Float &sipStrings_QtMultimedia[18350]
#define sipNameNr_Genre 18356
#define sipName_Genre &sipStrings_QtMultimedia[18356]
#define sipNameNr_Ready 14419
#define sipName_Ready &sipStrings_QtMultimedia[14419]
#define sipNameNr_Sport 18362
#define sipName_Sport &sipStrings_QtMultimedia[18362]
#define sipNameNr_State 4609
#define sipName_State &sipStrings_QtMultimedia[4609]
#define sipNameNr_Title 15883
#define sipName_Title &sipStrings_QtMultimedia[15883]
#define sipNameNr_Top40 18368
#define sipName_Top40 &sipStrings_QtMultimedia[18368]
#define sipNameNr_clear 18374
#define sipName_clear &sipStrings_QtMultimedia[18374]
#define sipNameNr_codec 18380
#define sipName_codec &sipStrings_QtMultimedia[18380]
#define sipNameNr_error 18386
#define sipName_error &sipStrings_QtMultimedia[18386]
#define sipNameNr_event 18392
#define sipName_event &sipStrings_QtMultimedia[18392]
#define sipNameNr_flags 18398
#define sipName_flags &sipStrings_QtMultimedia[18398]
#define sipNameNr_flush 18404
#define sipName_flush &sipStrings_QtMultimedia[18404]
#define sipNameNr_focus 18410
#define sipName_focus &sipStrings_QtMultimedia[18410]
#define sipNameNr_image 18416
#define sipName_image &sipStrings_QtMultimedia[18416]
#define sipNameNr_loops 18422
#define sipName_loops &sipStrings_QtMultimedia[18422]
#define sipNameNr_media 7384
#define sipName_media &sipStrings_QtMultimedia[7384]
#define sipNameNr_pause 18428
#define sipName_pause &sipStrings_QtMultimedia[18428]
#define sipNameNr_realm 18434
#define sipName_realm &sipStrings_QtMultimedia[18434]
#define sipNameNr_reset 7745
#define sipName_reset &sipStrings_QtMultimedia[7745]
#define sipNameNr_start 18440
#define sipName_start &sipStrings_QtMultimedia[18440]
#define sipNameNr_state 18446
#define sipName_state &sipStrings_QtMultimedia[18446]
#define sipNameNr_steps 18452
#define sipName_steps &sipStrings_QtMultimedia[18452]
#define sipNameNr_unmap 18458
#define sipName_unmap &sipStrings_QtMultimedia[18458]
#define sipNameNr_video 18464
#define sipName_video &sipStrings_QtMultimedia[18464]
#define sipNameNr_width 18470
#define sipName_width &sipStrings_QtMultimedia[18470]
#define sipNameNr_winId 18476
#define sipName_winId &sipStrings_QtMultimedia[18476]
#define sipNameNr_Auto 9837
#define sipName_Auto &sipStrings_QtMultimedia[9837]
#define sipNameNr_Band 8711
#define sipName_Band &sipStrings_QtMultimedia[8711]
#define sipNameNr_Busy 18482
#define sipName_Busy &sipStrings_QtMultimedia[18482]
#define sipNameNr_Date 18487
#define sipName_Date &sipStrings_QtMultimedia[18487]
#define sipNameNr_Flag 1397
#define sipName_Flag &sipStrings_QtMultimedia[1397]
#define sipNameNr_Loop 7594
#define sipName_Loop &sipStrings_QtMultimedia[7594]
#define sipNameNr_Mode 224
#define sipName_Mode &sipStrings_QtMultimedia[224]
#define sipNameNr_Mood 18492
#define sipName_Mood &sipStrings_QtMultimedia[18492]
#define sipNameNr_News 18497
#define sipName_News &sipStrings_QtMultimedia[18497]
#define sipNameNr_Null 18242
#define sipName_Null &sipStrings_QtMultimedia[18242]
#define sipNameNr_Role 3958
#define sipName_Role &sipStrings_QtMultimedia[3958]
#define sipNameNr_Size 13457
#define sipName_Size &sipStrings_QtMultimedia[13457]
#define sipNameNr_Soft 18502
#define sipName_Soft &sipStrings_QtMultimedia[18502]
#define sipNameNr_Talk 12995
#define sipName_Talk &sipStrings_QtMultimedia[12995]
#define sipNameNr_Year 18507
#define sipName_Year &sipStrings_QtMultimedia[18507]
#define sipNameNr_area 18512
#define sipName_area &sipStrings_QtMultimedia[18512]
#define sipNameNr_band 18517
#define sipName_band &sipStrings_QtMultimedia[18517]
#define sipNameNr_bind 18305
#define sipName_bind &sipStrings_QtMultimedia[18305]
#define sipNameNr_bits 18522
#define sipName_bits &sipStrings_QtMultimedia[18522]
#define sipNameNr_data 18527
#define sipName_data &sipStrings_QtMultimedia[18527]
#define sipNameNr_file 18532
#define sipName_file &sipStrings_QtMultimedia[18532]
#define sipNameNr_load 18312
#define sipName_load &sipStrings_QtMultimedia[18312]
#define sipNameNr_name 9359
#define sipName_name &sipStrings_QtMultimedia[9359]
#define sipNameNr_next 18537
#define sipName_next &sipStrings_QtMultimedia[18537]
#define sipNameNr_play 18542
#define sipName_play &sipStrings_QtMultimedia[18542]
#define sipNameNr_read 18547
#define sipName_read &sipStrings_QtMultimedia[18547]
#define sipNameNr_save 18552
#define sipName_save &sipStrings_QtMultimedia[18552]
#define sipNameNr_size 18557
#define sipName_size &sipStrings_QtMultimedia[18557]
#define sipNameNr_stop 18562
#define sipName_stop &sipStrings_QtMultimedia[18562]
#define sipNameNr_swap 18567
#define sipName_swap &sipStrings_QtMultimedia[18567]
#define sipNameNr_type 18572
#define sipName_type &sipStrings_QtMultimedia[18572]
#define sipNameNr_FM2 18577
#define sipName_FM2 &sipStrings_QtMultimedia[18577]
#define sipNameNr_ISO 18581
#define sipName_ISO &sipStrings_QtMultimedia[18581]
#define sipNameNr_end 18096
#define sipName_end &sipStrings_QtMultimedia[18096]
#define sipNameNr_hue 18585
#define sipName_hue &sipStrings_QtMultimedia[18585]
#define sipNameNr_map 18460
#define sipName_map &sipStrings_QtMultimedia[18460]
#define sipNameNr_run 18589
#define sipName_run &sipStrings_QtMultimedia[18589]
#define sipNameNr_url 18593
#define sipName_url &sipStrings_QtMultimedia[18593]
#define sipNameNr_AM 18597
#define sipName_AM &sipStrings_QtMultimedia[18597]
#define sipNameNr_FM 18600
#define sipName_FM &sipStrings_QtMultimedia[18600]
#define sipNameNr_LW 18603
#define sipName_LW &sipStrings_QtMultimedia[18603]
#define sipNameNr_SW 18606
#define sipName_SW &sipStrings_QtMultimedia[18606]

#define sipMalloc                   sipAPI_QtMultimedia->api_malloc
#define sipFree                     sipAPI_QtMultimedia->api_free
#define sipBuildResult              sipAPI_QtMultimedia->api_build_result
#define sipCallMethod               sipAPI_QtMultimedia->api_call_method
#define sipCallProcedureMethod      sipAPI_QtMultimedia->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtMultimedia->api_call_error_handler
#define sipParseResultEx            sipAPI_QtMultimedia->api_parse_result_ex
#define sipParseResult              sipAPI_QtMultimedia->api_parse_result
#define sipParseArgs                sipAPI_QtMultimedia->api_parse_args
#define sipParseKwdArgs             sipAPI_QtMultimedia->api_parse_kwd_args
#define sipParsePair                sipAPI_QtMultimedia->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtMultimedia->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtMultimedia->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtMultimedia->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtMultimedia->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtMultimedia->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtMultimedia->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtMultimedia->api_add_exception
#define sipNoFunction               sipAPI_QtMultimedia->api_no_function
#define sipNoMethod                 sipAPI_QtMultimedia->api_no_method
#define sipAbstractMethod           sipAPI_QtMultimedia->api_abstract_method
#define sipBadClass                 sipAPI_QtMultimedia->api_bad_class
#define sipBadCatcherResult         sipAPI_QtMultimedia->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtMultimedia->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtMultimedia->api_bad_operator_arg
#define sipTrace                    sipAPI_QtMultimedia->api_trace
#define sipTransferBack             sipAPI_QtMultimedia->api_transfer_back
#define sipTransferTo               sipAPI_QtMultimedia->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtMultimedia->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtMultimedia->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtMultimedia->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtMultimedia->api_voidptr_type
#define sipGetPyObject              sipAPI_QtMultimedia->api_get_pyobject
#define sipGetAddress               sipAPI_QtMultimedia->api_get_address
#define sipGetMixinAddress          sipAPI_QtMultimedia->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtMultimedia->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtMultimedia->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtMultimedia->api_call_hook
#define sipEndThread                sipAPI_QtMultimedia->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtMultimedia->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtMultimedia->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtMultimedia->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtMultimedia->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtMultimedia->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtMultimedia->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtMultimedia->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtMultimedia->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtMultimedia->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtMultimedia->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtMultimedia->api_convert_to_bool
#define sipReleaseType              sipAPI_QtMultimedia->api_release_type
#define sipConvertFromType          sipAPI_QtMultimedia->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtMultimedia->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtMultimedia->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtMultimedia->api_convert_from_enum
#define sipGetState                 sipAPI_QtMultimedia->api_get_state
#define sipExportSymbol             sipAPI_QtMultimedia->api_export_symbol
#define sipImportSymbol             sipAPI_QtMultimedia->api_import_symbol
#define sipFindType                 sipAPI_QtMultimedia->api_find_type
#define sipBytes_AsChar             sipAPI_QtMultimedia->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtMultimedia->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtMultimedia->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtMultimedia->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtMultimedia->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtMultimedia->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtMultimedia->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtMultimedia->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtMultimedia->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtMultimedia->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtMultimedia->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtMultimedia->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtMultimedia->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtMultimedia->api_get_reference
#define sipKeepReference            sipAPI_QtMultimedia->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtMultimedia->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtMultimedia->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtMultimedia->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtMultimedia->api_type_scope
#define sipResolveTypedef           sipAPI_QtMultimedia->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtMultimedia->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtMultimedia->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtMultimedia->api_init_mixin
#define sipExportModule             sipAPI_QtMultimedia->api_export_module
#define sipInitModule               sipAPI_QtMultimedia->api_init_module
#define sipGetInterpreter           sipAPI_QtMultimedia->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtMultimedia->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtMultimedia->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtMultimedia->api_py_type_dict
#define sipPyTypeName               sipAPI_QtMultimedia->api_py_type_name
#define sipGetCFunction             sipAPI_QtMultimedia->api_get_c_function
#define sipGetMethod                sipAPI_QtMultimedia->api_get_method
#define sipFromMethod               sipAPI_QtMultimedia->api_from_method
#define sipGetDate                  sipAPI_QtMultimedia->api_get_date
#define sipFromDate                 sipAPI_QtMultimedia->api_from_date
#define sipGetDateTime              sipAPI_QtMultimedia->api_get_datetime
#define sipFromDateTime             sipAPI_QtMultimedia->api_from_datetime
#define sipGetTime                  sipAPI_QtMultimedia->api_get_time
#define sipFromTime                 sipAPI_QtMultimedia->api_from_time
#define sipIsUserType               sipAPI_QtMultimedia->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtMultimedia->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtMultimedia->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtMultimedia->api_unicode_write
#define sipUnicodeData              sipAPI_QtMultimedia->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtMultimedia->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtMultimedia->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtMultimedia->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtMultimedia->api_is_derived_class
#define sipGetUserObject            sipAPI_QtMultimedia->api_get_user_object
#define sipSetUserObject            sipAPI_QtMultimedia->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtMultimedia->api_register_event_handler
#define sipConvertToArray           sipAPI_QtMultimedia->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtMultimedia->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtMultimedia->api_enable_gc
#define sipPrintObject              sipAPI_QtMultimedia->api_print_object
#define sipLong_AsChar              sipAPI_QtMultimedia->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtMultimedia->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtMultimedia->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtMultimedia->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtMultimedia->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtMultimedia->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtMultimedia->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtMultimedia->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtMultimedia->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtMultimedia->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtMultimedia->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtMultimedia->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtMultimedia->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtMultimedia->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtMultimedia->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtMultimedia->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtMultimedia->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtMultimedia->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtMultimedia->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtMultimedia->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtMultimedia->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtMultimedia->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtMultimedia->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtMultimedia->api_connect_rx
#define sipConvertRx                sipAPI_QtMultimedia->api_convert_rx
#define sipDisconnectRx             sipAPI_QtMultimedia->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtMultimedia->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtMultimedia->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtMultimedia->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtMultimedia->api_same_slot
#define sipSaveSlot                 sipAPI_QtMultimedia->api_save_slot
#define sipVisitSlot                sipAPI_QtMultimedia->api_visit_slot
#define sipIsPyMethod               sipAPI_QtMultimedia->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtMultimedia[];

#define sipType_QAbstractVideoBuffer sipExportedTypes_QtMultimedia[0]

#define sipType_QAbstractVideoBuffer_MapMode sipExportedTypes_QtMultimedia[2]

#define sipType_QAbstractVideoBuffer_HandleType sipExportedTypes_QtMultimedia[1]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAbstractVideoBuffer;

#define sipType_QVideoFilterRunnable sipExportedTypes_QtMultimedia[158]

#define sipType_QVideoFilterRunnable_RunFlag sipExportedTypes_QtMultimedia[159]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFilterRunnable;

#define sipType_QVideoFilterRunnable_RunFlags sipExportedTypes_QtMultimedia[160]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFilterRunnable_RunFlags;

#define sipType_QAbstractVideoFilter sipExportedTypes_QtMultimedia[3]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAbstractVideoFilter;

#define sipType_QAbstractVideoSurface sipExportedTypes_QtMultimedia[4]

#define sipType_QAbstractVideoSurface_Error sipExportedTypes_QtMultimedia[5]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAbstractVideoSurface;

#define sipType_QAudio sipExportedTypes_QtMultimedia[6]

#define sipType_QAudio_VolumeScale sipExportedTypes_QtMultimedia[11]

#define sipType_QAudio_Role sipExportedTypes_QtMultimedia[9]

#define sipType_QAudio_Mode sipExportedTypes_QtMultimedia[8]

#define sipType_QAudio_State sipExportedTypes_QtMultimedia[10]

#define sipType_QAudio_Error sipExportedTypes_QtMultimedia[7]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudio;

#define sipType_QAudioBuffer sipExportedTypes_QtMultimedia[12]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioBuffer;

#define sipType_QMediaObject sipExportedTypes_QtMultimedia[108]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaObject;

#define sipType_QAudioDecoder sipExportedTypes_QtMultimedia[13]

#define sipType_QAudioDecoder_Error sipExportedTypes_QtMultimedia[14]

#define sipType_QAudioDecoder_State sipExportedTypes_QtMultimedia[15]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDecoder;

#define sipType_QMediaControl sipExportedTypes_QtMultimedia[104]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaControl;

#define sipType_QAudioDecoderControl sipExportedTypes_QtMultimedia[16]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDecoderControl;

#define sipType_QAudioDeviceInfo sipExportedTypes_QtMultimedia[17]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDeviceInfo;

#define sipType_QAudioEncoderSettingsControl sipExportedTypes_QtMultimedia[19]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioEncoderSettingsControl;

#define sipType_QAudioFormat sipExportedTypes_QtMultimedia[20]

#define sipType_QAudioFormat_Endian sipExportedTypes_QtMultimedia[21]

#define sipType_QAudioFormat_SampleType sipExportedTypes_QtMultimedia[22]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioFormat;

#define sipType_QAudioInput sipExportedTypes_QtMultimedia[23]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioInput;

#define sipType_QAudioInputSelectorControl sipExportedTypes_QtMultimedia[24]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioInputSelectorControl;

#define sipType_QAudioOutput sipExportedTypes_QtMultimedia[25]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioOutput;

#define sipType_QAudioOutputSelectorControl sipExportedTypes_QtMultimedia[26]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioOutputSelectorControl;

#define sipType_QAudioProbe sipExportedTypes_QtMultimedia[27]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioProbe;

#define sipType_QMediaBindableInterface sipExportedTypes_QtMultimedia[101]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaBindableInterface;

#define sipType_QMediaRecorder sipExportedTypes_QtMultimedia[119]

#define sipType_QMediaRecorder_Error sipExportedTypes_QtMultimedia[120]

#define sipType_QMediaRecorder_Status sipExportedTypes_QtMultimedia[122]

#define sipType_QMediaRecorder_State sipExportedTypes_QtMultimedia[121]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaRecorder;

#define sipType_QAudioRecorder sipExportedTypes_QtMultimedia[28]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioRecorder;

#define sipType_QAudioRoleControl sipExportedTypes_QtMultimedia[29]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioRoleControl;

#define sipType_QCamera sipExportedTypes_QtMultimedia[30]

#define sipType_QCamera_Position sipExportedTypes_QtMultimedia[39]

#define sipType_QCamera_LockType sipExportedTypes_QtMultimedia[37]

#define sipType_QCamera_LockChangeReason sipExportedTypes_QtMultimedia[35]

#define sipType_QCamera_LockStatus sipExportedTypes_QtMultimedia[36]

#define sipType_QCamera_Error sipExportedTypes_QtMultimedia[33]

#define sipType_QCamera_CaptureMode sipExportedTypes_QtMultimedia[31]

#define sipType_QCamera_State sipExportedTypes_QtMultimedia[40]

#define sipType_QCamera_Status sipExportedTypes_QtMultimedia[41]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCamera;

#define sipType_QCamera_CaptureModes sipExportedTypes_QtMultimedia[32]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCamera_CaptureModes;

#define sipType_QCamera_LockTypes sipExportedTypes_QtMultimedia[38]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCamera_LockTypes;

#define sipType_QCamera_FrameRateRange sipExportedTypes_QtMultimedia[34]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCamera_FrameRateRange;

#define sipType_QCameraCaptureBufferFormatControl sipExportedTypes_QtMultimedia[42]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraCaptureBufferFormatControl;

#define sipType_QCameraCaptureDestinationControl sipExportedTypes_QtMultimedia[43]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraCaptureDestinationControl;

#define sipType_QCameraControl sipExportedTypes_QtMultimedia[44]

#define sipType_QCameraControl_PropertyChangeType sipExportedTypes_QtMultimedia[45]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraControl;

#define sipType_QCameraExposure sipExportedTypes_QtMultimedia[46]

#define sipType_QCameraExposure_MeteringMode sipExportedTypes_QtMultimedia[50]

#define sipType_QCameraExposure_ExposureMode sipExportedTypes_QtMultimedia[47]

#define sipType_QCameraExposure_FlashMode sipExportedTypes_QtMultimedia[48]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraExposure;

#define sipType_QCameraExposure_FlashModes sipExportedTypes_QtMultimedia[49]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraExposure_FlashModes;

#define sipType_QCameraExposureControl sipExportedTypes_QtMultimedia[51]

#define sipType_QCameraExposureControl_ExposureParameter sipExportedTypes_QtMultimedia[52]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraExposureControl;

#define sipType_QCameraFeedbackControl sipExportedTypes_QtMultimedia[53]

#define sipType_QCameraFeedbackControl_EventType sipExportedTypes_QtMultimedia[54]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFeedbackControl;

#define sipType_QCameraFlashControl sipExportedTypes_QtMultimedia[55]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFlashControl;

#define sipType_QCameraFocusZone sipExportedTypes_QtMultimedia[61]

#define sipType_QCameraFocusZone_FocusZoneStatus sipExportedTypes_QtMultimedia[62]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocusZone;

#define sipType_QCameraFocus sipExportedTypes_QtMultimedia[56]

#define sipType_QCameraFocus_FocusPointMode sipExportedTypes_QtMultimedia[59]

#define sipType_QCameraFocus_FocusMode sipExportedTypes_QtMultimedia[57]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocus;

#define sipType_QCameraFocus_FocusModes sipExportedTypes_QtMultimedia[58]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocus_FocusModes;

#define sipType_QCameraFocusControl sipExportedTypes_QtMultimedia[60]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocusControl;

#define sipType_QCameraImageCapture sipExportedTypes_QtMultimedia[63]

#define sipType_QCameraImageCapture_CaptureDestination sipExportedTypes_QtMultimedia[64]

#define sipType_QCameraImageCapture_DriveMode sipExportedTypes_QtMultimedia[66]

#define sipType_QCameraImageCapture_Error sipExportedTypes_QtMultimedia[67]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageCapture;

#define sipType_QCameraImageCapture_CaptureDestinations sipExportedTypes_QtMultimedia[65]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageCapture_CaptureDestinations;

#define sipType_QCameraImageCaptureControl sipExportedTypes_QtMultimedia[68]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageCaptureControl;

#define sipType_QCameraImageProcessing sipExportedTypes_QtMultimedia[69]

#define sipType_QCameraImageProcessing_ColorFilter sipExportedTypes_QtMultimedia[70]

#define sipType_QCameraImageProcessing_WhiteBalanceMode sipExportedTypes_QtMultimedia[71]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageProcessing;

#define sipType_QCameraImageProcessingControl sipExportedTypes_QtMultimedia[72]

#define sipType_QCameraImageProcessingControl_ProcessingParameter sipExportedTypes_QtMultimedia[73]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageProcessingControl;

#define sipType_QCameraInfo sipExportedTypes_QtMultimedia[74]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraInfo;

#define sipType_QCameraInfoControl sipExportedTypes_QtMultimedia[75]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraInfoControl;

#define sipType_QCameraLocksControl sipExportedTypes_QtMultimedia[76]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraLocksControl;

#define sipType_QCameraViewfinderSettings sipExportedTypes_QtMultimedia[77]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraViewfinderSettings;

#define sipType_QCameraViewfinderSettingsControl sipExportedTypes_QtMultimedia[78]

#define sipType_QCameraViewfinderSettingsControl_ViewfinderParameter sipExportedTypes_QtMultimedia[80]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraViewfinderSettingsControl;

#define sipType_QCameraViewfinderSettingsControl2 sipExportedTypes_QtMultimedia[79]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraViewfinderSettingsControl2;

#define sipType_QCameraZoomControl sipExportedTypes_QtMultimedia[81]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCameraZoomControl;

#define sipType_QCustomAudioRoleControl sipExportedTypes_QtMultimedia[82]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QCustomAudioRoleControl;

#define sipType_QImageEncoderControl sipExportedTypes_QtMultimedia[84]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QImageEncoderControl;

#define sipType_QMediaAudioProbeControl sipExportedTypes_QtMultimedia[99]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaAudioProbeControl;

#define sipType_QMediaAvailabilityControl sipExportedTypes_QtMultimedia[100]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaAvailabilityControl;

#define sipType_QMediaContainerControl sipExportedTypes_QtMultimedia[102]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaContainerControl;

#define sipType_QMediaContent sipExportedTypes_QtMultimedia[103]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaContent;

#define sipType_QAudioEncoderSettings sipExportedTypes_QtMultimedia[18]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QAudioEncoderSettings;

#define sipType_QVideoEncoderSettings sipExportedTypes_QtMultimedia[156]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoEncoderSettings;

#define sipType_QImageEncoderSettings sipExportedTypes_QtMultimedia[85]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QImageEncoderSettings;

#define sipType_QMediaGaplessPlaybackControl sipExportedTypes_QtMultimedia[105]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaGaplessPlaybackControl;

#define sipType_QMediaMetaData sipExportedTypes_QtMultimedia[106]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaMetaData;

#define sipType_QMediaNetworkAccessControl sipExportedTypes_QtMultimedia[107]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaNetworkAccessControl;

#define sipType_QGraphicsVideoItem sipExportedTypes_QtMultimedia[83]

#define sipType_QVideoWidget sipExportedTypes_QtMultimedia[169]

#define sipType_QMediaPlayer sipExportedTypes_QtMultimedia[109]

#define sipType_QMediaPlayer_Error sipExportedTypes_QtMultimedia[110]

#define sipType_QMediaPlayer_Flag sipExportedTypes_QtMultimedia[111]

#define sipType_QMediaPlayer_MediaStatus sipExportedTypes_QtMultimedia[113]

#define sipType_QMediaPlayer_State sipExportedTypes_QtMultimedia[114]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayer;

#define sipType_QMediaPlayer_Flags sipExportedTypes_QtMultimedia[112]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayer_Flags;

#define sipType_QMediaPlayerControl sipExportedTypes_QtMultimedia[115]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayerControl;

#define sipType_QMediaPlaylist sipExportedTypes_QtMultimedia[116]

#define sipType_QMediaPlaylist_Error sipExportedTypes_QtMultimedia[117]

#define sipType_QMediaPlaylist_PlaybackMode sipExportedTypes_QtMultimedia[118]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlaylist;

#define sipType_QMediaRecorderControl sipExportedTypes_QtMultimedia[123]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaRecorderControl;

#define sipType_QMediaResource sipExportedTypes_QtMultimedia[124]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaResource;

#define sipType_QMediaService sipExportedTypes_QtMultimedia[125]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaService;

#define sipType_QMediaStreamsControl sipExportedTypes_QtMultimedia[126]

#define sipType_QMediaStreamsControl_StreamType sipExportedTypes_QtMultimedia[127]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaStreamsControl;

#define sipType_QMediaTimeInterval sipExportedTypes_QtMultimedia[128]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaTimeInterval;

#define sipType_QMediaTimeRange sipExportedTypes_QtMultimedia[129]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaTimeRange;

#define sipType_QMediaVideoProbeControl sipExportedTypes_QtMultimedia[130]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMediaVideoProbeControl;

#define sipType_QMetaDataReaderControl sipExportedTypes_QtMultimedia[131]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMetaDataReaderControl;

#define sipType_QMetaDataWriterControl sipExportedTypes_QtMultimedia[132]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMetaDataWriterControl;

#define sipType_QMultimedia sipExportedTypes_QtMultimedia[133]

#define sipType_QMultimedia_AvailabilityStatus sipExportedTypes_QtMultimedia[134]

#define sipType_QMultimedia_EncodingMode sipExportedTypes_QtMultimedia[135]

#define sipType_QMultimedia_EncodingQuality sipExportedTypes_QtMultimedia[136]

#define sipType_QMultimedia_SupportEstimate sipExportedTypes_QtMultimedia[137]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QMultimedia;

#define sipType_QRadioData sipExportedTypes_QtMultimedia[138]

#define sipType_QRadioData_ProgramType sipExportedTypes_QtMultimedia[140]

#define sipType_QRadioData_Error sipExportedTypes_QtMultimedia[139]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QRadioData;

#define sipType_QRadioDataControl sipExportedTypes_QtMultimedia[141]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QRadioDataControl;

#define sipType_QRadioTuner sipExportedTypes_QtMultimedia[142]

#define sipType_QRadioTuner_SearchMode sipExportedTypes_QtMultimedia[145]

#define sipType_QRadioTuner_StereoMode sipExportedTypes_QtMultimedia[147]

#define sipType_QRadioTuner_Error sipExportedTypes_QtMultimedia[144]

#define sipType_QRadioTuner_Band sipExportedTypes_QtMultimedia[143]

#define sipType_QRadioTuner_State sipExportedTypes_QtMultimedia[146]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QRadioTuner;

#define sipType_QRadioTunerControl sipExportedTypes_QtMultimedia[148]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QRadioTunerControl;

#define sipType_QSound sipExportedTypes_QtMultimedia[149]

#define sipType_QSound_Loop sipExportedTypes_QtMultimedia[150]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QSound;

#define sipType_QSoundEffect sipExportedTypes_QtMultimedia[151]

#define sipType_QSoundEffect_Status sipExportedTypes_QtMultimedia[153]

#define sipType_QSoundEffect_Loop sipExportedTypes_QtMultimedia[152]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QSoundEffect;

#define sipType_QVideoDeviceSelectorControl sipExportedTypes_QtMultimedia[155]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoDeviceSelectorControl;

#define sipType_QVideoEncoderSettingsControl sipExportedTypes_QtMultimedia[157]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoEncoderSettingsControl;

#define sipType_QVideoFrame sipExportedTypes_QtMultimedia[161]

#define sipType_QVideoFrame_PixelFormat sipExportedTypes_QtMultimedia[163]

#define sipType_QVideoFrame_FieldType sipExportedTypes_QtMultimedia[162]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoFrame;

#define sipType_QVideoProbe sipExportedTypes_QtMultimedia[164]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoProbe;

#define sipType_QVideoRendererControl sipExportedTypes_QtMultimedia[165]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoRendererControl;

#define sipType_QVideoSurfaceFormat sipExportedTypes_QtMultimedia[166]

#define sipType_QVideoSurfaceFormat_YCbCrColorSpace sipExportedTypes_QtMultimedia[168]

#define sipType_QVideoSurfaceFormat_Direction sipExportedTypes_QtMultimedia[167]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoSurfaceFormat;

#define sipType_QVideoWindowControl sipExportedTypes_QtMultimedia[170]

extern sipClassTypeDef sipTypeDef_QtMultimedia_QVideoWindowControl;

#define sipType_QList_0100QMediaTimeInterval sipExportedTypes_QtMultimedia[96]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaTimeInterval;

#define sipType_QList_0100QMediaContent sipExportedTypes_QtMultimedia[94]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaContent;

#define sipType_QVector_0101QAbstractVideoSurface sipExportedTypes_QtMultimedia[154]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QVector_0101QAbstractVideoSurface;

#define sipType_QList_0100QCameraInfo sipExportedTypes_QtMultimedia[92]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCameraInfo;

#define sipType_QList_0100QCamera_FrameRateRange sipExportedTypes_QtMultimedia[90]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCamera_FrameRateRange;

#define sipType_QList_0100QCameraViewfinderSettings sipExportedTypes_QtMultimedia[93]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCameraViewfinderSettings;

#define sipType_QList_0100QString sipExportedTypes_QtMultimedia[97]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QString;

#define sipType_QList_0100QAudioDeviceInfo sipExportedTypes_QtMultimedia[87]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QAudioDeviceInfo;

#define sipType_QList_0100QMediaResource sipExportedTypes_QtMultimedia[95]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QMediaResource;

#define sipType_QList_0100QCameraFocusZone sipExportedTypes_QtMultimedia[91]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QCameraFocusZone;

#define sipType_QList_0100QAudio_Role sipExportedTypes_QtMultimedia[86]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QAudio_Role;

#define sipType_QList_0100QAudioFormat_SampleType sipExportedTypes_QtMultimedia[89]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QAudioFormat_SampleType;

#define sipType_QList_0100QAudioFormat_Endian sipExportedTypes_QtMultimedia[88]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QAudioFormat_Endian;

#define sipType_QList_0100QVideoFrame_PixelFormat sipExportedTypes_QtMultimedia[98]

extern sipMappedTypeDef sipTypeDef_QtMultimedia_QList_0100QVideoFrame_PixelFormat;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtMultimedia;
extern sipExportedModuleDef sipModuleAPI_QtMultimedia;
extern sipTypeDef *sipExportedTypes_QtMultimedia[];

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtMultimedia_QtCore[21].it_td

#define sipType_QObject sipImportedTypes_QtMultimedia_QtCore[9].it_td

#define sipType_QIODevice sipImportedTypes_QtMultimedia_QtCore[3].it_td

#define sipType_QByteArray sipImportedTypes_QtMultimedia_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtMultimedia_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtMultimedia_QtCore[17].it_td

#define sipType_QChildEvent sipImportedTypes_QtMultimedia_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtMultimedia_QtCore[8].it_td

#define sipType_QPointF sipImportedTypes_QtMultimedia_QtCore[11].it_td

#define sipType_QRect sipImportedTypes_QtMultimedia_QtCore[12].it_td

#define sipType_QRectF sipImportedTypes_QtMultimedia_QtCore[13].it_td

#define sipType_QSize sipImportedTypes_QtMultimedia_QtCore[14].it_td

#define sipType_QUrl sipImportedTypes_QtMultimedia_QtCore[18].it_td

#define sipType_QVariant sipImportedTypes_QtMultimedia_QtCore[19].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtMultimedia_QtCore[4].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtMultimedia_QtCore[5].it_td

#define sipType_QPair_1800_1800 sipImportedTypes_QtMultimedia_QtCore[10].it_td

#define sipType_QVariantMap sipImportedTypes_QtMultimedia_QtCore[20].it_td

#define sipType_QStringList sipImportedTypes_QtMultimedia_QtCore[16].it_td

#define sipType_QList_2400 sipImportedTypes_QtMultimedia_QtCore[7].it_td

#define sipType_QList_1800 sipImportedTypes_QtMultimedia_QtCore[6].it_td

#define sipType_QString sipImportedTypes_QtMultimedia_QtCore[15].it_td

#define sipType_quintptr sipImportedTypes_QtMultimedia_QtCore[22].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimedia_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtMultimedia_QtCore[];

#define sipType_QImage sipImportedTypes_QtMultimedia_QtGui[0].it_td

#define sipType_QImage_Format sipImportedTypes_QtMultimedia_QtGui[1].it_td

#define sipType_QList_0100QSize sipImportedTypes_QtMultimedia_QtGui[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimedia_QtGui[];

#define sipType_QNetworkConfiguration sipImportedTypes_QtMultimedia_QtNetwork[1].it_td

#define sipType_QNetworkRequest sipImportedTypes_QtMultimedia_QtNetwork[2].it_td

#define sipType_QList_0100QNetworkConfiguration sipImportedTypes_QtMultimedia_QtNetwork[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtMultimedia_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtMultimedia_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtMultimedia_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtMultimedia_qt_metacast;

#endif
